@@ -1,52 +1,37 @@
-#' @title Create data cubes using local files
+#' @title Create raster data cubes using local files
+#' @name .local_raster_cube
 #' @keywords internal
 #' @noRd
 #' @param source       Data source (one of \code{"AWS"}, \code{"BDC"},
 #' \code{"DEAFRICA"}, \code{"MPC"}, \code{"USGS"}).
 #' @param collection   Image collection in data source (To find out
 #'  the supported collections, use \code{\link{sits_list_collections}()}).
-#' @param data_dir     Local directory where images are stored.
-#' @param vector_dir    Local director where vector files are stored
-#'                     (for local vector cubes - character vector of length 1)
+#' @param data_dir     Local directory where images are stored.)
 #' @param parse_info   Parsing information for local files.
-#' @param version      Version id for local files.
 #' @param delim        Delimiter for parsing local files.
 #' @param tiles        Tiles from the collection to be included in
 #'                     the cube (see details below).
 #' @param bands        Spectral bands and indices to be included
 #'                     in the cube (optional).
-#' @param vector_band  Band for vector data cube
-#' @param labels       Labels associated to the classes (only for result cubes)
 #' @param start_date,end_date Initial and final dates to include
 #'                     images from the collection in the cube (optional).
 #' @param multicores   Number of workers for parallel processing
-#' @param progress     Show a progress bar?
+#' @param progress     Show a progress bar?z
 #' @param ...          Other parameters to be passed for specific types.
 #' @return A \code{tibble} describing the contents of a local data cube.
-.local_cube <- function(source,
-                        collection,
-                        data_dir,
-                        vector_dir,
-                        parse_info,
-                        version,
-                        delim,
-                        tiles,
-                        bands,
-                        vector_band,
-                        labels,
-                        start_date,
-                        end_date,
-                        multicores,
-                        progress, ...) {
+.local_raster_cube <- function(source,
+                               collection,
+                               data_dir,
+                               parse_info,
+                               delim,
+                               tiles,
+                               bands,
+                               start_date,
+                               end_date,
+                               multicores,
+                               progress, ...) {
     # set caller to show in errors
-    .check_set_caller(".local_cube")
-    # initialize vector items
-    vector_items <- NULL
-    # is this a cube with results?
-    results_cube <- .check_is_results_cube(bands, labels)
-
-    # set the correct parse_info
-    parse_info <- .conf_parse_info(parse_info, results_cube)
+    .check_set_caller(".local_raster_cube")
 
     # bands in upper case for raw cubes, lower case for results cubes
     bands <- .band_set_case(bands)
@@ -61,58 +46,25 @@
         end_date = end_date,
         bands = bands
     )
-    if (.has(vector_dir)) {
-        # set the correct parse_info
-        parse_info <- .conf("results_parse_info_def")
-
-        vector_items <- .local_cube_items_vector_new(
-            vector_dir = vector_dir,
-            parse_info = parse_info,
-            version = version,
-            delim = delim,
-            start_date = start_date,
-            end_date = end_date,
-            vector_band = vector_band
-        )
-    }
-
-    # filter bands in items (only for raw image cube)
-    if (!results_cube) {
-        raster_items <- .local_cube_items_bands_select(
-            source = source,
-            collection = collection,
-            bands = bands,
-            items = raster_items
-        )
-    }
+    raster_items <- .local_cube_items_bands_select(
+        source = source,
+        collection = collection,
+        bands = bands,
+        items = raster_items
+    )
     # filter tiles
     if (.has(tiles)) {
         raster_items <- .local_cube_items_tiles_select(
             tiles = tiles,
             items = raster_items
         )
-        if (.has(vector_items)) {
-            vector_items <- .local_cube_items_tiles_select(
-                tiles = tiles,
-                items = vector_items
-            )
-        }
     }
     # build file_info for the items
-    if (results_cube) {
-        raster_items <- .local_results_cube_file_info(
-            items = raster_items,
-            multicores = multicores,
-            progress = progress
-        )
-    } else {
-        raster_items <- .local_cube_file_info(
-            items = raster_items,
-            multicores = multicores,
-            progress = progress
-        )
-    }
-
+    raster_items <- .local_cube_file_info(
+        items = raster_items,
+        multicores = multicores,
+        progress = progress
+    )
     # get all tiles
     tiles <- unique(raster_items[["tile"]])
 
@@ -121,15 +73,6 @@
         # filter tile
         items_tile <- dplyr::filter(raster_items, .data[["tile"]] == !!tile)
         # create result cube
-        if (results_cube) {
-            tile_cube <- .local_results_items_cube(
-                source = source,
-                collection = collection,
-                raster_items = items_tile,
-                labels = labels
-            )
-            return(tile_cube)
-        }
         # create EO cube
         tile_cube <- .local_cube_items_cube(
             source = source,
@@ -142,44 +85,156 @@
 
     # handle class cubes from external sources
     cube <- .local_cube_handle_class_cube(source, collection, cube)
+    class(cube) <- .cube_s3class(cube)
+    cube
+}
+#' @title Create results data cubes using local files
+#' @name .local_results_cube
+#' @keywords internal
+#' @noRd
+#' @param source       Data source (one of \code{"AWS"}, \code{"BDC"},
+#' \code{"DEAFRICA"}, \code{"MPC"}, \code{"USGS"}).
+#' @param collection   Image collection in data source (To find out
+#'  the supported collections, use \code{\link{sits_list_collections}()}).
+#' @param data_dir     Local directory where images are stored.
+#' @param parse_info   Parsing information for local files.
+#' @param version      Version id for local files.
+#' @param delim        Delimiter for parsing local files.
+#' @param tiles        Tiles from the collection to be included in
+#'                     the cube (see details below).
+#' @param bands        Spectral bands and indices to be included
+#'                     in the cube (optional).
+#' @param labels       Labels associated to the classes (only for result cubes)
+#' @param multicores   Number of workers for parallel processing
+#' @param progress     Show a progress bar?z
+#' @param ...          Other parameters to be passed for specific types.
+#' @return A \code{tibble} describing the contents of a local data cube.
+.local_results_cube <- function(source,
+                                collection,
+                                data_dir,
+                                parse_info,
+                                version,
+                                delim,
+                                tiles,
+                                bands,
+                                labels,
+                                multicores,
+                                progress, ...) {
+    # set caller to show in errors
+    .check_set_caller(".local_results_cube")
+    # is this a cube with results?
+    .check_is_results_cube(bands, labels)
 
-    if (.has(vector_items)) {
-        cube <- .local_cube_include_vector_info(cube, vector_items)
-    }
+    # set the correct parse_info
+    parse_info <- .conf_parse_info(parse_info, results_cube = TRUE)
 
-    if (results_cube) {
-        result_class <- .conf("sits_results_s3_class")[[bands]]
-        class(cube) <- c(
-            result_class, "derived_cube",
-            "raster_cube", class(cube)
+    # bands in upper case for raw cubes, lower case for results cubes
+    bands <- .band_set_case(bands)
+
+    # make query and retrieve items
+    raster_items <- .local_cube_items_raster_new(
+        data_dir = data_dir,
+        parse_info = parse_info,
+        version = version,
+        delim = delim,
+        start_date = NULL,
+        end_date = NULL,
+        bands = bands
+    )
+    # filter tiles
+    if (.has(tiles)) {
+        raster_items <- .local_cube_items_tiles_select(
+            tiles = tiles,
+            items = raster_items
         )
-    } else {
-        class(cube) <- .cube_s3class(cube)
-        if (.has(vector_items)) {
-            if (vector_band == "segments") {
-                class(cube) <- c("segs_cube", "vector_cube", class(cube))
-            } else if (vector_band == "probs") {
-                class(cube) <- c("probs_vector_cube",
-                                 "derived_vector_cube",
-                                 "segs_cube",
-                                 "vector_cube",
-                                 class(cube))
-            } else if (vector_band == "class") {
-                class(cube) <- c("class_vector_cube",
-                                 "derived_vector_cube",
-                                 "segs_cube",
-                                 "vector_cube",
-                                 class(cube))
-
-            }
-        }
     }
+    # build file_info for the items
+    raster_items <- .local_results_cube_file_info(
+        items = raster_items,
+        multicores = multicores,
+        progress = progress
+    )
+    # get all tiles
+    tiles <- unique(raster_items[["tile"]])
+
+    # make a cube for each tile (rows)
+    cube <- .map_dfr(tiles, function(tile) {
+        # filter tile
+        items_tile <- dplyr::filter(raster_items, .data[["tile"]] == !!tile)
+        # create result cube
+        .local_results_items_cube(
+            source = source,
+            collection = collection,
+            raster_items = items_tile,
+            labels = labels
+        )
+    })
+
+    # handle class cubes from external sources
+    cube <- .local_cube_handle_class_cube(source, collection, cube)
+    result_class <- .conf("sits_results_s3_class")[[bands]]
+    class(cube) <- c(
+        result_class, "derived_cube",
+        "raster_cube", class(cube)
+    )
     # check if labels match in the case of class cube
     if (inherits(cube, "class_cube")) {
         .check_labels_class_cube(cube)
     }
 
-    return(cube)
+    cube
+}
+#' @title Create vector items using local files
+#' @name .local_vector_items
+#' @keywords internal
+#' @noRd
+#' @param source       Data source (one of \code{"AWS"}, \code{"BDC"},
+#' \code{"DEAFRICA"}, \code{"MPC"}, \code{"USGS"}).
+#' @param collection   Image collection in data source (To find out
+#'  the supported collections, use \code{\link{sits_list_collections}()}).
+#' @param vector_dir    Local director where vector files are stored
+#'                     (for local vector cubes - character vector of length 1)
+#' @param vector_band  Band for vector data cube
+#' @param parse_info   Parsing information for local vector files.
+#' @param version      Version id for local files.
+#' @param delim        Delimiter for parsing local files.
+#' @param labels       Labels associated to the classes (only for result cubes)
+#' @param start_date,end_date Initial and final dates to include
+#'                     images from the collection in the cube (optional).
+#' @param multicores   Number of workers for parallel processing
+#' @param progress     Show a progress bar?z
+#' @param ...          Other parameters to be passed for specific types.
+#' @return A \code{tibble} describing the contents of a local data cube.
+.local_vector_items <- function(source,
+                                collection,
+                                vector_dir,
+                                vector_band,
+                                parse_info,
+                                version,
+                                delim,
+                                start_date,
+                                end_date,
+                                multicores,
+                                progress, ...) {
+    # set caller to show in errors
+    .check_set_caller(".local_vector_items")
+
+    # bands in upper case for raw cubes, lower case for results cubes
+    vector_band <- .band_set_case(vector_band)
+    # set the correct parse_info
+    if (!.has(parse_info)) {
+        parse_info <- .conf("results_parse_info_def")
+    }
+
+    .local_cube_items_vector_new(
+        vector_dir = vector_dir,
+        parse_info = parse_info,
+        version = version,
+        delim = delim,
+        start_date = start_date,
+        end_date = end_date,
+        vector_band = vector_band
+    )
 }
 
 #' @title Return raster items for local data cube
@@ -206,7 +261,7 @@
 
     # is this a cube with results?
     if (.has(bands) &&
-        bands[[1]] %in% .conf("sits_results_bands")) {
+        bands[[1L]] %in% .conf("sits_results_bands")) {
         results_cube <- TRUE
     } else {
         results_cube <- FALSE
@@ -217,10 +272,10 @@
     # list the files in the data directory
     img_files <- list.files(
         path = data_dir,
-        pattern = paste0("\\.(", paste0(file_ext, collapse = "|"), ")$")
+        pattern = paste0("\\.(", paste(file_ext, collapse = "|"), ")$")
     )
-    # postcondition
-    .check_chr_parameter(img_files, allow_empty = FALSE, len_min = 1)
+    # post condition
+    .check_that(.has(img_files))
 
     # remove the extension
     img_files_noext <- tools::file_path_sans_ext(img_files)
@@ -228,16 +283,13 @@
     img_files_lst <- strsplit(img_files_noext, split = delim, fixed = TRUE)
     # which image files in directory match the parse info?
     are_img_files_ok <- purrr::map_lgl(img_files_lst, function(img_file) {
-        if (length(img_file) == length(parse_info))
-            return(TRUE)
-        else
-            return(FALSE)
+        length(img_file) == length(parse_info)
     })
     # select the images that match the file info
     img_files_ok <- img_files_lst[are_img_files_ok]
 
     # post condition
-    .check_that(length(img_files_ok) > 0)
+    .check_that(.has(img_files_ok))
 
     # get valid files
     img_files_filt <- img_files[are_img_files_ok]
@@ -270,14 +322,13 @@
             msg = .conf("messages", ".local_cube_items_version")
         )
         # get only the first band
-        band <- bands[[1]]
+        band <- bands[[1L]]
         # get the information on the required band, dates and path
         items <- items |>
             # bands are case insensitive (converted to lower case)
             dplyr::mutate(band = tolower(.data[["band"]])) |>
             # add path
-            dplyr::mutate(path = paste(data_dir,
-                                           img_files_filt, sep = "/")) |>
+            dplyr::mutate(path = file.path(data_dir, img_files_filt)) |>
             # filter by the band
             dplyr::filter(.data[["band"]] == !!band) |>
             # filter by the version
@@ -314,7 +365,7 @@
             dplyr::mutate(band = toupper(.data[["band"]])) |>
             # add path
             dplyr::mutate(
-                path = paste(!!data_dir, !!img_files_filt, sep = "/")
+                path = file.path(!!data_dir, !!img_files_filt)
             ) |>
             # select the relevant parts
             dplyr::select(
@@ -344,8 +395,8 @@
         }
     }
     # post-condition
-    .check_that(nrow(items) > 0)
-    return(items)
+    .check_that(.has(items))
+    items
 }
 #' @title Return raster items for local data cube
 #' @keywords internal
@@ -374,10 +425,10 @@
     # list the vector files in the data directory
     gpkg_files <- list.files(
         path = vector_dir,
-        pattern = paste0("\\.(", paste0(file_ext, collapse = "|"), ")$")
+        pattern = paste0("\\.(", paste(file_ext, collapse = "|"), ")$")
     )
     # post-condition
-    gpkg_files_path <- paste0(vector_dir, "/", gpkg_files)
+    gpkg_files_path <- file.path(vector_dir, gpkg_files)
     .check_that(all(file.exists(gpkg_files_path)))
 
     # remove the extension
@@ -386,10 +437,7 @@
     gpkg_files_lst <- strsplit(gpkg_files_noext, split = delim, fixed = TRUE)
     # check gkpg files
     are_gpkg_files_ok <- purrr::map_lgl(gpkg_files_lst, function(gpkg_file) {
-        if (length(gpkg_file) == length(parse_info)) {
-            return(TRUE)
-        }
-        return(FALSE)
+        length(gpkg_file) == length(parse_info)
     })
     # subset gkpg files
     gpkg_files_ok <- gpkg_files_lst[are_gpkg_files_ok]
@@ -402,7 +450,7 @@
     # joint the list into a tibble and convert bands name to upper case
     items <- suppressMessages(
         tibble::as_tibble(gpkg_files_mx,
-                          .name_repair = "universal"
+            .name_repair = "universal"
         )
     )
     # check if bands exist
@@ -425,8 +473,7 @@
         # bands are case insensitive (converted to lower case)
         dplyr::mutate(band = tolower(.data[["band"]])) |>
         # add path
-        dplyr::mutate(path = paste(vector_dir,
-                                   gpkg_files_filt, sep = "/")) |>
+        dplyr::mutate(path = file.path(vector_dir, gpkg_files_filt)) |>
         # filter by the band
         dplyr::filter(.data[["band"]] == !!vector_band) |>
         # filter by the version
@@ -459,8 +506,8 @@
         dplyr::arrange(.data[["start_date"]])
 
     # post-condition
-    .check_that(nrow(items) > 0)
-    return(items)
+    .check_that(.has(items))
+    items
 }
 #' @title Select items by bands
 #' @keywords internal
@@ -498,7 +545,7 @@
         # select the requested bands
         items <- dplyr::filter(items, .data[["band"]] %in% !!bands)
     }
-    return(items)
+    items
 }
 #' @title Select items by tiles
 #' @keywords internal
@@ -517,8 +564,7 @@
         within = unique(items[["tile"]])
     )
     # select the requested tiles
-    items <- dplyr::filter(items, .data[["tile"]] %in% !!tiles)
-    return(items)
+    dplyr::filter(items, .data[["tile"]] %in% !!tiles)
 }
 
 #' @title Build local cube file_info
@@ -533,8 +579,8 @@
                                   progress) {
     # set caller to show in errors
     .check_set_caller(".local_cube_file_info")
-    # post-condition
-    .check_that(nrow(items) > 0)
+    # pre-condition
+    .check_that(.has(items))
     # add feature id (fid)
     items <- dplyr::group_by(items, .data[["tile"]], .data[["date"]]) |>
         dplyr::mutate(fid = paste0(dplyr::cur_group_id())) |>
@@ -568,27 +614,26 @@
         bad_assets <- purrr::map_lgl(assets_info, purrr::is_character)
         item <- item[!bad_assets, ]
 
-        # bind items and assets info
-        result <- list(
+        # bind items and assets info and return result
+        list(
             item = dplyr::bind_cols(
                 item, dplyr::bind_rows(assets_info[!bad_assets])
             ),
             error = unlist(assets_info[bad_assets])
         )
-        return(result)
     }, progress = progress)
 
     items <- purrr::map(results_lst, `[[`, "item")
     errors <- unlist(purrr::map(results_lst, `[[`, "error"))
-    if (length(errors) > 0) {
+    if (.has(errors)) {
         warning(.conf("messages", ".local_cube_file_info_error"),
-                toString(errors),
-                call. = FALSE, immediate. = TRUE
+            toString(errors),
+            call. = FALSE, immediate. = TRUE
         )
     }
-    items <- dplyr::bind_rows(items) |>
+    # bind rows into a tibble and then organizw by date, fid, and band
+    dplyr::bind_rows(items) |>
         dplyr::arrange(.data[["date"]], .data[["fid"]], .data[["band"]])
-    return(items)
 }
 
 #' @title Build local cube file_info for results cubes
@@ -602,8 +647,8 @@
     # set caller to show in errors
     .check_set_caller(".local_results_cube_file_info")
 
-    # post-condition
-    .check_that(nrow(items) > 0)
+    # pre-condition
+    .check_that(.has(items))
 
     # prepare parallel requests
     if (is.null(sits_env[["cluster"]])) {
@@ -643,19 +688,19 @@
             error = unlist(assets_info[bad_assets])
         )
 
-        return(results)
+        results
     }, progress = progress)
 
     items_lst <- purrr::map(results_lst, `[[`, "item")
     errors <- unlist(purrr::map(results_lst, `[[`, "error"))
-    if (length(errors) > 0) {
+    if (.has(errors)) {
         warning(.conf("messages", ".local_cube_file_info_error"),
-                toString(errors),
-                call. = FALSE, immediate. = TRUE
+            toString(errors),
+            call. = FALSE, immediate. = TRUE
         )
     }
-    items <- dplyr::bind_rows(items_lst)
-    return(items)
+    # return items as a data frame
+    dplyr::bind_rows(items_lst)
 }
 
 #' @title Build data cube tibble
@@ -674,7 +719,11 @@
     # pre-condition
     .check_local_items(items)
     # get crs from file_info
-    crs <- unique(items[["crs"]])
+    # # deal with special case of HLS collections
+    if (collection == "HLSL30" || collection == "HLSS30")
+        crs <- items[1, ][["crs"]]
+    else
+        crs <- unique(items[["crs"]])
     # get tile from file_info
     tile <- unique(items[["tile"]])
     # make a new file info for one tile
@@ -698,7 +747,7 @@
     )
 
     # create a tibble to store the metadata
-    cube_tile <- .cube_create(
+    .cube_create(
         source = source,
         collection = collection,
         satellite = .source_collection_satellite(source, collection),
@@ -711,7 +760,6 @@
         crs = crs,
         file_info = file_info
     )
-    return(cube_tile)
 }
 
 #' @title Build data cube tibble for results cube
@@ -755,7 +803,7 @@
         ))
     )
     # create a tibble to store the metadata
-    cube_tile <- .cube_create(
+    .cube_create(
         source = source,
         collection = collection,
         satellite = .source_collection_satellite(source, collection),
@@ -769,7 +817,6 @@
         labels = labels,
         file_info = file_info
     )
-    return(cube_tile)
 }
 
 #' @title Handle details related to class cubes from external sources.
@@ -798,7 +845,7 @@
 }
 
 .local_cube_include_vector_info <- function(cube, vector_items) {
-    cube <- slider::slide_dfr(cube, function(tile) {
+    slider::slide_dfr(cube, function(tile) {
         item <- dplyr::filter(vector_items, .data[["tile"]] == !!tile[["tile"]])
         vector_info <- tibble::tibble(
             band = item[["band"]],
@@ -814,11 +861,6 @@
         )
         tile[["labels"]] <- list(.label_gpkg_file(item[["path"]]))
         tile[["vector_info"]] <- list(vector_info)
-        return(tile)
+        tile
     })
-
-    return(cube)
 }
-
-
-
