@@ -31,36 +31,39 @@ sits_to_csv <- function(data, file = NULL) {
 #' @export
 sits_to_csv.sits <- function(data, file = NULL) {
     # check the samples are valid
-    data <- .check_samples(data)
+    .check_samples(data)
+    data <- .samples_convert_to_sits(data)
     # check the file name is valid
-    if (.has(file))
+    if (.has(file)) {
         .check_file(
             x = file,
             extensions = "csv",
             file_exists = FALSE
         )
+    }
     # get metadata
     csv <- .csv_metadata_from_samples(data)
     # write the CSV file
-    if (.has(file))
+    if (.has(file)) {
         utils::write.csv(csv, file, row.names = FALSE, quote = FALSE)
+    }
     return(csv)
 }
 #' @rdname sits_to_csv
 #' @export
 sits_to_csv.tbl_df <- function(data, file) {
-    data <- tibble::as_tibble(data)
-    if (all(.conf("sits_tibble_cols") %in% colnames(data)))
+    if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
         class(data) <- c("sits", class(data))
-    else
+    } else {
         stop(.conf("messages", "sits_to_csv_default"))
-    data <- sits_to_csv(data, file)
-    return(invisible(data))
+    }
+    sits_to_csv(data, file)
 }
 #' @rdname sits_to_csv
 #' @export
 sits_to_csv.default <- function(data, file) {
-    stop(.conf("messages", "sits_to_csv_default"))
+    data <- tibble::as_tibble(data)
+    sits_to_csv(data, file)
 }
 #' @title Export a a full sits tibble to the CSV format
 #'
@@ -81,23 +84,27 @@ sits_to_csv.default <- function(data, file) {
 #' @return            Return data.frame with CSV columns (optional)
 #'
 #' @examples
+#' csv_ts <- sits_timeseries_to_csv(cerrado_2classes)
 #' csv_file <- paste0(tempdir(), "/cerrado_2classes_ts.csv")
 #' sits_timeseries_to_csv(cerrado_2classes, file = csv_file)
 #' @export
 #'
 sits_timeseries_to_csv <- function(data, file = NULL) {
     # check the samples are valid
-    data <- .check_samples(data)
+    .check_samples(data)
+    data <- .samples_convert_to_sits(data)
     csv_1 <- .csv_metadata_from_samples(data)
-    csv_2 <- .predictors(data)[-2:0]
-    csv_combined <- dplyr::bind_cols(csv_1, csv_2)
+    csv_2 <- .predictors(data)[-2L:0L]
+    csv_ts <- dplyr::bind_cols(csv_1, csv_2)
 
     # write the CSV file
-    if (.has(file))
-        utils::write.csv(csv_combined,
-                         file,
-                         row.names = FALSE,
-                         quote = FALSE)
-
-    return(csv_combined)
+    if (.has(file)) {
+        utils::write.csv(csv_ts,
+            file,
+            row.names = FALSE,
+            quote = FALSE
+        )
+    } else {
+        return(csv_ts)
+    }
 }
