@@ -2,14 +2,14 @@
 #' @name sits_mosaic
 #'
 #' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
-#' @author Rolf Simoes,     \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
+#' @author Felipe Carlos,   \email{efelipecarlos@@gmail.com}
 #'
 #' @description Creates a mosaic of all tiles of a sits cube.
-#' Mosaics can be created from EO cubes and derived cubes.
-#' In sits EO cubes, the mosaic will be generated for each band and date.
-#' It is recommended to filter the image with the less cloud cover to create
-#' a mosaic for the EO cubes.
-#' It is possible to provide a \code{roi} to crop the mosaic.
+#' Mosaics can be created from both regularized ARD images or from classified
+#' maps. In the case of ARD images, a mosaic will be produce for each band/date
+#' combination. It is better to first regularize the data cubes and then
+#' use \code{sits_mosaic}.
 #'
 #' @param cube       A sits data cube.
 #' @param crs        A target coordinate reference system of raster mosaic.
@@ -34,10 +34,9 @@
 #'  named lat/long values (\code{lon_min}, \code{lon_max},
 #'    \code{lat_min}, \code{lat_max}).
 #'
-#'  The user should specify the crs of the mosaic since in many cases the
-#'  input images will be in different coordinate systems. For example,
-#'  when mosaicking Sentinel-2 images the inputs will be in general in
-#'  different UTM grid zones.
+#'  When the data cube has tiles that cover different UTM grid zones,
+#'  the user should specify the CRS of the mosaic. We use
+#'  "EPSG:3857" (Pseudo-Mercator) as the default.
 #'
 #' @examples
 #' if (sits_run_examples()) {
@@ -86,7 +85,7 @@
 sits_mosaic <- function(cube,
                         crs = "EPSG:3857",
                         roi = NULL,
-                        multicores = 2,
+                        multicores = 2L,
                         output_dir,
                         version = "v1",
                         progress = TRUE) {
@@ -94,12 +93,11 @@ sits_mosaic <- function(cube,
     # Pre-conditions
     .check_is_raster_cube(cube)
     .check_crs(crs)
-    .check_int_parameter(multicores, min = 1, max = 2048)
+    .check_int_parameter(multicores, min = 1L, max = 2048L)
     .check_output_dir(output_dir)
-    version <- .check_version(version)
-    .check_lgl_parameter(progress)
-    # version is case-insensitive in sits
-    version <- tolower(version)
+    # Check version and progress
+    version <- .message_version(version)
+    progress <- .message_progress(progress)
     # Spatial filter
     if (.has(roi)) {
         roi <- .roi_as_sf(roi)
