@@ -1,6 +1,7 @@
 #' @title  Obtain predictors for time series samples
 #' @name sits_predictors
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
 #' @description Predictors are X-Y values required for machine learning
 #' algorithms, organized as a data table where each row corresponds
 #' to a training sample. The first two columns of the predictors table
@@ -13,16 +14,62 @@
 #'
 #' @examples
 #' if (sits_run_examples()) {
-#'     pred <- sits_predictors(samples_modis_ndvi)
+#'     # Include a new machine learning function (multiple linear regression)
+#'     # function that returns mlr model based on a sits sample tibble
+#'
+#'     sits_mlr <- function(samples = NULL, formula = sits_formula_linear(),
+#'                          n_weights = 20000, maxit = 2000) {
+#'         # create a training function
+#'         train_fun <- function(samples) {
+#'             # Data normalization
+#'             ml_stats <- sits_stats(samples)
+#'             train_samples <- sits_predictors(samples)
+#'             train_samples <- sits_pred_normalize(
+#'                 pred = train_samples,
+#'                 stats = ml_stats
+#'             )
+#'             formula <- formula(train_samples[, -1])
+#'             # call method and return the trained model
+#'             result_mlr <- nnet::multinom(
+#'                 formula = formula,
+#'                 data = train_samples,
+#'                 maxit = maxit,
+#'                 MaxNWts = n_weights,
+#'                 trace = FALSE,
+#'                 na.action = stats::na.fail
+#'             )
+#'
+#'             # construct model predict closure function and returns
+#'             predict_fun <- function(values) {
+#'                 # retrieve the prediction (values and probs)
+#'                 prediction <- tibble::as_tibble(
+#'                     stats::predict(result_mlr,
+#'                         newdata = values,
+#'                         type = "probs"
+#'                     )
+#'                 )
+#'                 return(prediction)
+#'             }
+#'             class(predict_fun) <- c("sits_model", class(predict_fun))
+#'             return(predict_fun)
+#'         }
+#'         result <- sits_factory_function(samples, train_fun)
+#'         return(result)
+#'     }
+#'     # create an mlr model using a set of samples
+#'     mlr_model <- sits_train(samples_modis_ndvi, sits_mlr)
+#'     # classify a point
+#'     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
+#'     point_class <- sits_classify(point_ndvi, mlr_model, multicores = 1)
+#'     plot(point_class)
 #' }
 #'
 #' @export
 sits_predictors <- function(samples) {
     .check_set_caller("sits_predictors")
     .check_na_null_parameter(samples)
-    samples <- .check_samples_ts(samples)
-    pred <- .predictors(samples)
-    return(pred)
+    .check_samples_ts(samples)
+    .predictors(samples)
 }
 
 #' @title  Obtain numerical values of predictors for time series samples
@@ -49,11 +96,10 @@ sits_predictors <- function(samples) {
 #' }
 #' @export
 sits_pred_features <- function(pred) {
-    features <- .pred_features(pred)
-    return(features)
+    .pred_features(pred)
 }
 #' @title  Obtain categorical id and predictor labels for time series samples
-#' @name sits_pred_reference
+#' @name sits_pred_references
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @description Predictors are X-Y values required for machine learning
 #' algorithms, organized as a data table where each row corresponds
@@ -73,8 +119,7 @@ sits_pred_features <- function(pred) {
 #' }
 #' @export
 sits_pred_references <- function(pred) {
-    ref <- .pred_references(pred)
-    return(ref)
+    .pred_references(pred)
 }
 #' @title  Normalize predictor values
 #' @name sits_pred_normalize
@@ -104,8 +149,7 @@ sits_pred_normalize <- function(pred, stats) {
     .check_set_caller("sits_pred_normalize")
     .check_na_null_parameter(pred)
     .check_na_null_parameter(stats)
-    pred <- .pred_normalize(pred, stats)
-    return(pred)
+    .pred_normalize(pred, stats)
 }
 #' @title  Obtain a fraction of the predictors data frame
 #' @name sits_pred_sample
@@ -131,8 +175,7 @@ sits_pred_normalize <- function(pred, stats) {
 #' }
 #' @export
 sits_pred_sample <- function(pred, frac) {
-    sample <- .pred_sample(pred, frac)
-    return(sample)
+    .pred_sample(pred, frac)
 }
 #' @title  Obtain statistics for all sample bands
 #' @name sits_stats
@@ -159,6 +202,5 @@ sits_pred_sample <- function(pred, frac) {
 #' }
 #' @export
 sits_stats <- function(samples) {
-    stats <- .samples_stats(samples)
-    return(stats)
+    .samples_stats(samples)
 }
