@@ -1,5 +1,6 @@
 #' @title Build a regular data cube from an irregular one
-#'
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @name sits_regularize
 #'
 #' @description Produces regular data cubes for analysis-ready data (ARD)
@@ -10,7 +11,7 @@
 #' For this reason, subsets of these collection need to be converted to
 #' regular data cubes before further processing and data analysis.
 #' This function requires users to include the cloud band in their ARD-based
-#' data cubes.
+#' data cubes. This function uses the \code{gdalcubes} package.
 #'
 #' @references Appel, Marius; Pebesma, Edzer. On-demand processing of data cubes
 #'  from satellite image collections with the gdalcubes library. Data, v. 4,
@@ -26,53 +27,89 @@
 #' @param res         Spatial resolution of regularized images (in meters).
 #' @param output_dir  Valid directory for storing regularized images.
 #' @param timeline    User-defined timeline for regularized cube.
-#' @param roi         A named \code{numeric} vector with a region of interest.
+#' @param roi         Region of interest (see notes below).
+#' @param crs         Coordinate Reference System (CRS) of the roi.
+#'                     (see details below).
 #' @param tiles       Tiles to be produced.
 #' @param grid_system Grid system to be used for the output images.
 #' @param multicores  Number of cores used for regularization;
 #'                    used for parallel processing of input (integer)
-#' @param grid_system A character with the grid system that images will be
-#'                    cropped.
 #' @param progress    show progress bar?
 #'
 #'
 #' @note
+#' The main \code{sits} classification workflow has the following steps:
+#' \enumerate{
+#'      \item{\code{\link[sits]{sits_cube}}: selects a ARD image collection from
+#'          a cloud provider.}
+#'      \item{\code{\link[sits]{sits_cube_copy}}: copies an ARD image collection
+#'          from a cloud provider to a local directory for faster processing.}
+#'      \item{\code{\link[sits]{sits_regularize}}: create a regular data cube
+#'          from an ARD image collection.}
+#'      \item{\code{\link[sits]{sits_apply}}: create new indices by combining
+#'          bands of a  regular data cube (optional).}
+#'      \item{\code{\link[sits]{sits_get_data}}: extract time series
+#'          from a regular data cube based on user-provided labelled samples.}
+#'      \item{\code{\link[sits]{sits_train}}: train a machine learning
+#'          model based on image time series.}
+#'      \item{\code{\link[sits]{sits_classify}}: classify a data cube
+#'          using a machine learning model and obtain a probability cube.}
+#'      \item{\code{\link[sits]{sits_smooth}}: post-process a probability cube
+#'          using a spatial smoother to remove outliers and
+#'          increase spatial consistency.}
+#'      \item{\code{\link[sits]{sits_label_classification}}: produce a
+#'          classified map by selecting the label with the highest probability
+#'          from a smoothed cube.}
+#' }
+#'      The regularization operation converts subsets of image collections
+#'      available in cloud providers into regular data cubes. It is an essential
+#'      part of the \code{sits} workflow.
+#'      The input to \code{sits_regularize} should be an ARD cube
+#'      which includes the cloud band. The aggregation method used in
+#'      \code{sits_regularize} sorts the images based on cloud cover,
+#'      putting images with the least clouds at the top of the stack. Once
+#'      the stack of images is sorted, the method uses the first valid value to
+#'      create the temporal aggregation.
+#'
 #'      The "period" parameter is mandatory, and defines the time interval
-#'      between two images of the regularized cube. By default, the date
-#'      of the first image of the input cube is taken as the starting
+#'      between two images of the regularized cube. When combining
+#'      Sentinel-1A and Sentinel-1B images, experiments show that a
+#'      16-day period ("P16D") are a good default. Landsat images require
+#'      a longer period of one to three months.
+#'
+#'      By default, the date of the first image of the input cube
+#'      is taken as the starting
 #'      date for the regular cube. In many situations, users may want
 #'      to pre-define the required times using the "timeline" parameter.
 #'      The "timeline" parameter, if used, must contain a set of
 #'      dates which are compatible with the input cube.
 #'
+#'      To define a \code{roi} use one of:
+#'      \itemize{
+#'        \item{A path to a shapefile with polygons;}
+#'        \item{A \code{sfc} or \code{sf} object from \code{sf} package;}
+#'        \item{A \code{SpatExtent} object from \code{terra} package;}
+#'        \item{A named \code{vector} (\code{"lon_min"},
+#'             \code{"lat_min"}, \code{"lon_max"}, \code{"lat_max"}) in WGS84;}
+#'        \item{A named \code{vector} (\code{"xmin"}, \code{"xmax"},
+#'              \code{"ymin"}, \code{"ymax"}) with XY coordinates.}
+#'       }
 #'
-#' @note
-#'      The optional "roi" parameter defines a region of interest. It can be
-#'      an sf_object, a shapefile, or a bounding box vector with
-#'      named XY values ("xmin", "xmax", "ymin", "ymax") or
-#'      named lat/long values ("lat_min", "lat_max", "long_min", "long_max").
+#'      Defining a region of interest using \code{SpatExtent} or XY values not
+#'      in WGS84 requires the \code{crs} parameter to be specified.
 #'      \code{sits_regularize()} function will crop the images
 #'      that contain the region of interest().
 #'
-#' @note
-#'      The optional "tiles" parameter indicates which tiles of the
+#'      The optional \code{tiles} parameter indicates which tiles of the
 #'      input cube will be used for regularization.
 #'
-#' @note
-#'      The "grid_system" parameters allows the choice of grid system
-#'      for the regularized cube. Currently, the package supports
+#'      The \code{grid_system} parameter allows the user to
+#'      reproject the files to a grid system which is
+#'      different from that used in the ARD image collection of
+#'      the could provider. Currently, the package supports
 #'      the use of MGRS grid system and those used by the Brazil
 #'      Data Cube ("BDC_LG_V2" "BDC_MD_V2" "BDC_SM_V2").
 #'
-#' @note
-#'      The aggregation method used in \code{sits_regularize}
-#'      sorts the images based on cloud cover, where images with the fewest
-#'      clouds at the top of the stack. Once
-#'      the stack of images is sorted, the method uses the first valid value to
-#'      create the temporal aggregation.
-#' @note
-#'      The input (non-regular) ARD cube needs to include the cloud band for
-#'      the regularization to work.
 #'
 #' @return A \code{raster_cube} object with aggregated images.
 #'
@@ -97,8 +134,10 @@
 #'     )
 #'
 #'     ## Sentinel-1 SAR
-#'     roi <- c("lon_min" = -50.410, "lon_max" = -50.379,
-#'              "lat_min" = -10.1910, "lat_max" = -10.1573)
+#'     roi <- c(
+#'         "lon_min" = -50.410, "lon_max" = -50.379,
+#'         "lat_min" = -10.1910, "lat_max" = -10.1573
+#'     )
 #'     s1_cube_open <- sits_cube(
 #'         source = "MPC",
 #'         collection = "SENTINEL-1-GRD",
@@ -134,6 +173,7 @@ sits_regularize.raster_cube <- function(cube, ...,
                                         output_dir,
                                         timeline = NULL,
                                         roi = NULL,
+                                        crs = NULL,
                                         tiles = NULL,
                                         grid_system = NULL,
                                         multicores = 2L,
@@ -143,37 +183,32 @@ sits_regularize.raster_cube <- function(cube, ...,
     # check period
     .check_period(period)
     # check resolution
-    .check_num_parameter(res, exclusive_min = 0)
+    .check_num_parameter(res, exclusive_min = 0.0)
     # check output_dir
     output_dir <- .file_path_expand(output_dir)
     .check_output_dir(output_dir)
-    # check for ROI and tiles
-    if (!is.null(roi) || !is.null(tiles)) {
+    # check multicores
+    .check_num_parameter(multicores, min = 1L, max = 2048L)
+    # check progress
+    progress <- .message_progress(progress)
+    # Does cube contain cloud band? If not, issue a warning
+    .message_warnings_regularize_cloud(cube)
+    # ROI and tiles
+    if (.has(roi) || .has(tiles)) {
         .check_roi_tiles(roi, tiles)
     }
-    # check multicores
-    .check_num_parameter(multicores, min = 1, max = 2048)
-    # check progress
-    .check_progress(progress)
-    # Does cube contain cloud band?
-    if (!all(.cube_contains_cloud(cube)) && .check_warnings()) {
-        warning(.conf("messages", "sits_regularize_cloud"),
-                call. = FALSE,
-                immediate. = TRUE
-        )
-    }
     if (.has(roi)) {
-        crs <- NULL
-        if (.roi_type(roi) == "bbox" && !.has(roi[["crs"]])) {
-            crs <- .crs(cube)
-            if (length(crs) > 1 && .check_warnings()) {
-                warning(.conf("messages", "sits_regularize_crs"),
-                        call. = FALSE,
-                        immediate. = TRUE
-                )
-            }
-        }
-        roi <- .roi_as_sf(roi, default_crs = crs[[1]])
+        # standardize roi as sf
+        roi <- .roi_as_sf(roi, default_crs = crs)
+
+        # get cube as sf
+        cube_sf <- .cube_as_sf(cube)
+
+        # check if roi intersects with cube
+        .check_that(any(.intersects(cube_sf, roi)))
+    }
+    if (.has_not(roi) && .has_not(tiles)) {
+        roi <- .cube_as_sf(cube)
     }
     # Convert input cube to the user's provided grid system
     if (.has(grid_system)) {
@@ -187,15 +222,15 @@ sits_regularize.raster_cube <- function(cube, ...,
             )
         )
         .check_that(nrow(cube) > 0,
-                    msg = .conf("messages", "sits_regularize_roi")
+            msg = .conf("messages", "sits_regularize_roi")
         )
     }
-    # Display warning message in case STAC cube
-    if (!.cube_is_local(cube) && .check_warnings()) {
-        warning(.conf("messages", "sits_regularize_local"),
-                    call. = FALSE, immediate. = TRUE
-        )
+    if (.has(timeline)) {
+        timeline <- .as_date(timeline)
     }
+    # Display warning message in case regularization is done via STAC
+    # We prefer to regularize local files
+    .message_warnings_regularize_local(cube)
     # Regularize
     .gc_regularize(
         cube = cube,
@@ -218,26 +253,34 @@ sits_regularize.sar_cube <- function(cube, ...,
                                      timeline = NULL,
                                      grid_system = "MGRS",
                                      roi = NULL,
+                                     crs = NULL,
                                      tiles = NULL,
                                      multicores = 2L,
                                      progress = TRUE) {
     # Preconditions
     .check_raster_cube_files(cube)
     .check_period(period)
-    .check_num_parameter(res, exclusive_min = 0)
+    .check_num_parameter(res, exclusive_min = 0.0)
     output_dir <- .file_path_expand(output_dir)
     .check_output_dir(output_dir)
-    .check_num_parameter(multicores, min = 1, max = 2048)
-    .check_progress(progress)
-    # check for ROI and tiles
-    if (!is.null(roi) || !is.null(tiles)) {
+    .check_num_parameter(multicores, min = 1L, max = 2048L)
+    progress <- .message_progress(progress)
+    if (.has(grid_system)) {
+        .check_grid_system(grid_system)
+    }
+    # deal for ROI and tiles
+    if (.has(roi) || .has(tiles)) {
         .check_roi_tiles(roi, tiles)
-    } else {
+    }
+    if (.has(roi)) {
+        roi <- .roi_as_sf(roi, default_crs = crs)
+    }
+    if (.has_not(roi) && .has_not(tiles)) {
         roi <- .cube_as_sf(cube)
     }
-    if (.has(grid_system))
-        .check_grid_system(grid_system)
-
+    if (.has(timeline)) {
+        timeline <- .as_date(timeline)
+    }
     # Convert input sentinel1 cube to the user's provided grid system
     cube <- .reg_tile_convert(
         cube = cube,
@@ -258,7 +301,7 @@ sits_regularize.sar_cube <- function(cube, ...,
     on.exit(.parallel_stop(), add = TRUE)
 
     # Call regularize in parallel
-    cube <- .reg_cube(
+    .reg_cube(
         cube = cube,
         timeline = timeline,
         res = res,
@@ -267,7 +310,6 @@ sits_regularize.sar_cube <- function(cube, ...,
         output_dir = output_dir,
         progress = progress
     )
-    return(cube)
 }
 #' @rdname sits_regularize
 #' @export
@@ -277,25 +319,24 @@ sits_regularize.combined_cube <- function(cube, ...,
                                           output_dir,
                                           grid_system = NULL,
                                           roi = NULL,
+                                          crs = NULL,
                                           tiles = NULL,
                                           multicores = 2L,
                                           progress = TRUE) {
     # Preconditions
     .check_raster_cube_files(cube)
     .check_period(period)
-    .check_num_parameter(res, exclusive_min = 0)
+    .check_num_parameter(res, exclusive_min = 0.0)
     output_dir <- .file_path_expand(output_dir)
     .check_output_dir(output_dir)
-    .check_num_parameter(multicores, min = 1, max = 2048)
-    .check_progress(progress)
+    .check_num_parameter(multicores, min = 1L, max = 2048L)
+    progress <- .message_progress(progress)
     # check for ROI and tiles
     .check_roi_tiles(roi, tiles)
     if (.has(grid_system)) {
         .check_grid_system(grid_system)
-    } else {
-        if (any("NoTilingSystem" %in% .cube_tiles(cube) )) {
-            grid_system <- "MGRS"
-        }
+    } else if (any("NoTilingSystem" %in% .cube_tiles(cube))) {
+        grid_system <- "MGRS"
     }
     # Get a global timeline
     timeline <- .gc_get_valid_timeline(
@@ -304,7 +345,7 @@ sits_regularize.combined_cube <- function(cube, ...,
     # Grouping by unique values for each type of cube: sar, optical, etc..
     cubes <- dplyr::group_by(
         cube, .data[["source"]], .data[["collection"]], .data[["satellite"]]
-    ) |> dplyr::group_map(~{
+    ) |> dplyr::group_map(~ {
         class(.x) <- .cube_s3class(.x)
         .x
     }, .keep = TRUE)
@@ -316,6 +357,7 @@ sits_regularize.combined_cube <- function(cube, ...,
             period = period,
             res = res,
             roi = roi,
+            crs = crs,
             tiles = tiles,
             output_dir = output_dir,
             grid_system = grid_system,
@@ -324,8 +366,7 @@ sits_regularize.combined_cube <- function(cube, ...,
         )
     })
     # In case where more than two cubes need to be merged
-    combined_cube <- purrr::reduce(reg_cubes, sits_merge)
-    return(combined_cube)
+    purrr::reduce(reg_cubes, sits_merge)
 }
 #' @rdname sits_regularize
 #' @export
@@ -336,21 +377,87 @@ sits_regularize.rainfall_cube <- function(cube, ...,
                                           timeline = NULL,
                                           grid_system = "MGRS",
                                           roi = NULL,
+                                          crs = NULL,
                                           tiles = NULL,
                                           multicores = 2L,
                                           progress = TRUE) {
     # Preconditions
     .check_raster_cube_files(cube)
     .check_period(period)
-    .check_num_parameter(res, exclusive_min = 0)
+    .check_num_parameter(res, exclusive_min = 0.0)
     output_dir <- .file_path_expand(output_dir)
     .check_output_dir(output_dir)
-    .check_num_parameter(multicores, min = 1, max = 2048)
-    .check_progress(progress)
-    # check for ROI and tiles
-    if (!is.null(roi) || !is.null(tiles)) {
+    .check_num_parameter(multicores, min = 1L, max = 2048L)
+    progress <- .message_progress(progress)
+    # deal for ROI and tiles
+    if (.has(roi) || .has(tiles)) {
         .check_roi_tiles(roi, tiles)
-    } else {
+    }
+    if (.has(roi)) {
+        roi <- .roi_as_sf(roi, default_crs = crs)
+    }
+    if (.has_not(roi) && .has_not(tiles)) {
+        roi <- .cube_as_sf(cube)
+    }
+    if (.has(grid_system)) {
+        .check_grid_system(grid_system)
+    }
+    if (.has(timeline)) {
+        timeline <- .as_date(timeline)
+    }
+    # Convert input sentinel1 cube to the user's provided grid system
+    cube <- .reg_tile_convert(
+        cube = cube,
+        grid_system = grid_system,
+        roi = roi,
+        tiles = tiles
+    )
+    .check_content_data_frame(cube)
+    # Filter tiles
+    if (is.character(tiles)) {
+        cube <- .cube_filter_tiles(cube, tiles)
+    }
+    # Display warning message in case STAC cube
+    # Prepare parallel processing
+    .parallel_start(workers = multicores)
+    on.exit(.parallel_stop(), add = TRUE)
+    # Call regularize in parallel
+    .reg_cube(
+        cube = cube,
+        timeline = timeline,
+        res = res,
+        roi = roi,
+        period = period,
+        output_dir = output_dir,
+        progress = progress
+    )
+}
+#' @rdname sits_regularize
+#' @export
+sits_regularize.dem_cube <- function(cube, ...,
+                                     res,
+                                     output_dir,
+                                     grid_system = "MGRS",
+                                     roi = NULL,
+                                     crs = NULL,
+                                     tiles = NULL,
+                                     multicores = 2L,
+                                     progress = TRUE) {
+    # Preconditions
+    .check_raster_cube_files(cube)
+    .check_num_parameter(res, exclusive_min = 0L)
+    output_dir <- .file_path_expand(output_dir)
+    .check_output_dir(output_dir)
+    .check_num_parameter(multicores, min = 1L, max = 2048L)
+    progress <- .message_progress(progress)
+    # ROI and tiles
+    if (.has(roi) || .has(tiles)) {
+        .check_roi_tiles(roi, tiles)
+    }
+    if (.has(roi)) {
+        roi <- .roi_as_sf(roi, default_crs = crs)
+    }
+    if (.has_not(roi) && .has_not(tiles)) {
         roi <- .cube_as_sf(cube)
     }
     if (.has(grid_system)) {
@@ -363,64 +470,7 @@ sits_regularize.rainfall_cube <- function(cube, ...,
         roi = roi,
         tiles = tiles
     )
-    .check_that(nrow(cube) > 0,
-                msg = .conf("messages", "sits_regularize_roi")
-    )
-    # Filter tiles
-    if (is.character(tiles)) {
-        cube <- .cube_filter_tiles(cube, tiles)
-    }
-    # Display warning message in case STAC cube
-    # Prepare parallel processing
-    .parallel_start(workers = multicores)
-    on.exit(.parallel_stop(), add = TRUE)
-    # Call regularize in parallel
-    cube <- .reg_cube(
-        cube = cube,
-        timeline = timeline,
-        res = res,
-        roi = roi,
-        period = period,
-        output_dir = output_dir,
-        progress = progress
-    )
-    return(cube)
-}
-#' @rdname sits_regularize
-#' @export
-sits_regularize.dem_cube <- function(cube, ...,
-                                     res,
-                                     output_dir,
-                                     grid_system = "MGRS",
-                                     roi = NULL,
-                                     tiles = NULL,
-                                     multicores = 2L,
-                                     progress = TRUE) {
-    # Preconditions
-    .check_raster_cube_files(cube)
-    .check_num_parameter(res, exclusive_min = 0)
-    output_dir <- .file_path_expand(output_dir)
-    .check_output_dir(output_dir)
-    .check_num_parameter(multicores, min = 1, max = 2048)
-    .check_progress(progress)
-    # Get dots
-    dots <- list(...)
-    # check for ROI and tiles
-    if (!is.null(roi) || !is.null(tiles)) {
-        .check_roi_tiles(roi, tiles)
-    } else {
-        roi <- .cube_as_sf(cube)
-    }
-    # Convert input sentinel1 cube to the user's provided grid system
-    cube <- .reg_tile_convert(
-        cube = cube,
-        grid_system = grid_system,
-        roi = roi,
-        tiles = tiles
-    )
-    .check_that(nrow(cube) > 0,
-                msg = .conf("messages", "sits_regularize_roi")
-    )
+    .check_content_data_frame(cube)
     # Filter tiles
     if (is.character(tiles)) {
         cube <- .cube_filter_tiles(cube, tiles)
@@ -433,7 +483,7 @@ sits_regularize.dem_cube <- function(cube, ...,
     .parallel_start(workers = multicores)
     on.exit(.parallel_stop(), add = TRUE)
     # Call regularize in parallel
-    cube <- .reg_cube(
+    .reg_cube(
         cube = cube,
         timeline = NULL,
         res = res,
@@ -442,7 +492,77 @@ sits_regularize.dem_cube <- function(cube, ...,
         output_dir = output_dir,
         progress = progress
     )
-    return(cube)
+}
+#' @rdname sits_regularize
+#' @export
+sits_regularize.ogh_cube <- function(cube, ...,
+                                      period,
+                                      res,
+                                      output_dir,
+                                      timeline = NULL,
+                                      grid_system = "MGRS",
+                                      roi = NULL,
+                                      crs = NULL,
+                                      tiles = NULL,
+                                      multicores = 2L,
+                                      progress = TRUE) {
+    # Preconditions
+    .check_raster_cube_files(cube)
+    .check_period(period)
+    .check_num_parameter(res, exclusive_min = 0.0)
+    output_dir <- .file_path_expand(output_dir)
+    .check_output_dir(output_dir)
+    .check_num_parameter(multicores, min = 1L, max = 2048L)
+    progress <- .message_progress(progress)
+    # Manage s2 geometry
+    # hold s2 status
+    s2_status <- sf::sf_use_s2()
+    # Disable for applicable cubes
+    cube <- .cube_geometry_use_s2(cube, FALSE)
+    # Before exit, restore s2 status
+    on.exit(.cube_geometry_use_s2(cube, s2_status))
+    # deal for ROI and tiles
+    if (.has(roi) || .has(tiles)) {
+        .check_roi_tiles(roi, tiles)
+    }
+    if (.has(roi)) {
+        roi <- .roi_as_sf(roi, default_crs = crs)
+    }
+    if (.has_not(roi) && .has_not(tiles)) {
+        roi <- .cube_as_sf(cube)
+    }
+    if (.has(grid_system)) {
+        .check_grid_system(grid_system)
+    }
+    if (.has(timeline)) {
+        timeline <- .as_date(timeline)
+    }
+    # Convert input sentinel1 cube to the user's provided grid system
+    cube <- .reg_tile_convert(
+        cube = cube,
+        grid_system = grid_system,
+        roi = roi,
+        tiles = tiles
+    )
+    .check_content_data_frame(cube)
+    # Filter tiles
+    if (is.character(tiles)) {
+        cube <- .cube_filter_tiles(cube, tiles)
+    }
+    # Display warning message in case STAC cube
+    # Prepare parallel processing
+    .parallel_start(workers = multicores)
+    on.exit(.parallel_stop(), add = TRUE)
+    # Call regularize in parallel
+    .reg_cube(
+        cube = cube,
+        timeline = timeline,
+        res = res,
+        roi = roi,
+        period = period,
+        output_dir = output_dir,
+        progress = progress
+    )
 }
 #' @rdname sits_regularize
 #' @export
