@@ -4,7 +4,7 @@
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
 #' @author Felipe Souza, \email{lipecaso@@gmail.com}
-#' @author Alber Sanchez, \email{alber.ipia@@inpe.br}
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
 #' @author Charlotte Pelletier, \email{charlotte.pelletier@@univ-ubs.fr}
 #' @author Daniel Falbel, \email{dfalbel@@gmail.com}
 #'
@@ -42,9 +42,9 @@
 #'  2017 international joint conference on neural networks (IJCNN).
 #'
 #' @param samples            Time series with the training samples.
-#' @param samples_validation Time series with the validation samples. if the
-#'                           \code{samples_validation} parameter is provided,
-#'                           the \code{validation_split} parameter is ignored.
+#' @param samples_validation Time series with the validation samples. If
+#'                           the  parameter is provided,
+#'                           the \code{validation_split} is ignored.
 #' @param blocks             Number of 1D convolutional filters for
 #'                           each block of three layers.
 #' @param kernels            Size of the 1D convolutional kernels
@@ -82,7 +82,7 @@
 #'     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
 #'     cube <- sits_cube(
 #'         source = "BDC",
-#'         collection = "MOD13Q1-6",
+#'         collection = "MOD13Q1-6.1",
 #'         data_dir = data_dir
 #'     )
 #'     # classify a data cube
@@ -97,8 +97,7 @@
 #'     plot(bayes_cube)
 #'     # label the probability cube
 #'     label_cube <- sits_label_classification(
-#'         bayes_cube,
-#'         output_dir = tempdir()
+#'         bayes_cube, output_dir = tempdir()
 #'     )
 #'     # plot the labelled cube
 #'     plot(label_cube)
@@ -124,104 +123,76 @@ sits_resnet <- function(samples = NULL,
                         verbose = FALSE) {
     # set caller for error msg
     .check_set_caller("sits_resnet")
+    # Verifies if 'torch' and 'luz' packages is installed
+    .check_require_packages(c("torch", "luz"))
+    # documentation mode? verbose is FALSE
+    verbose <- .message_verbose(verbose)
     # Function that trains a torch model based on samples
     train_fun <- function(samples) {
+        # does not support working with DEM or other base data
+        if (inherits(samples, "sits_base")) {
+            stop(.conf("messages", "sits_train_base_data"), call. = FALSE)
+        }
         # Avoid add a global variable for 'self'
         self <- NULL
-        # Verifies if 'torch' and 'luz' packages is installed
-        .check_require_packages(c("torch", "luz"))
-        # Pre-conditions:
-        .check_samples_train(samples)
-        .check_int_parameter(blocks)
-        .check_int_parameter(kernels,
-            min = 1,
-            len_min = length(blocks),
-            len_max = length(blocks)
-        )
-        .check_int_parameter(epochs)
-        .check_int_parameter(batch_size)
-        .check_null_parameter(optimizer)
         # Check validation_split parameter if samples_validation is not passed
-        if (!.has(samples_validation))
-            .check_num_parameter(validation_split, exclusive_min = 0, max = 0.5)
+        if (is.null(samples_validation)) {
+            .check_num_parameter(validation_split, exclusive_min = 0.0, max = 0.5)
+        }
+        .check_pre_sits_resnet(
+            samples = samples,
+            blocks = blocks,
+            kernels = kernels,
+            epochs = epochs,
+            batch_size = batch_size,
+            lr_decay_epochs = lr_decay_epochs,
+            lr_decay_rate = lr_decay_rate,
+            patience = patience,
+            min_delta = min_delta,
+            verbose = verbose
+        )
         # Check opt_hparams
         # Get parameters list and remove the 'param' parameter
-        optim_params_function <- formals(optimizer)[-1]
-        if (!is.null(opt_hparams)) {
-            .check_lst_parameter(opt_hparams,
-                                 msg = .conf("messages", ".check_opt_hparams")
-            )
-            .check_chr_within(
-                x = names(opt_hparams),
-                within = names(optim_params_function),
-                msg = .conf("messages", ".check_opt_hparams")
-            )
-            optim_params_function <- utils::modifyList(
-                x = optim_params_function, val = opt_hparams
-            )
-        }
-        # Other pre-conditions:
-        .check_int_parameter(lr_decay_epochs)
-        .check_num_parameter(lr_decay_rate, exclusive_min = 0, max = 1)
-        .check_int_parameter(patience)
-        .check_num_parameter(min_delta, min = 0)
-        .check_lgl_parameter(verbose)
-
-        # Samples labels
-        labels <- sits_labels(samples)
-        # Samples bands
-        bands <- sits_bands(samples)
-        # Samples timeline
-        timeline <- sits_timeline(samples)
-
+        optim_params_function <- formals(optimizer)[-1L]
+        .check_opt_hparams(opt_hparams, optim_params_function)
+        optim_params_function <- utils::modifyList(
+            x = optim_params_function,
+            val = opt_hparams
+        )
+        # Sample labels
+        sample_labels <- .samples_labels(samples)
+        # Sample bands
+        bands <- .samples_bands(samples)
+        # Sample timeline
+        timeline <- .samples_timeline(samples)
         # Create numeric labels vector
-        code_labels <- seq_along(labels)
-        names(code_labels) <- labels
-
+        code_labels <- seq_along(sample_labels)
+        names(code_labels) <- sample_labels
         # Number of labels, bands, and number of samples (used below)
-        n_labels <- length(labels)
+        n_labels <- length(sample_labels)
         n_bands <- length(bands)
         n_times <- .samples_ntimes(samples)
-
         # Data normalization
         ml_stats <- .samples_stats(samples)
-        train_samples <- .predictors(samples)
-        train_samples <- .pred_normalize(pred = train_samples, stats = ml_stats)
 
-        # Post condition: is predictor data valid?
-        .check_predictors(pred = train_samples, samples = samples)
+        # Organize train and the test data
+        train_test_data <- .torch_train_test_samples(
+            samples = samples,
+            samples_validation = samples_validation,
+            ml_stats = ml_stats,
+            labels = sample_labels,
+            code_labels = code_labels,
+            timeline = timeline,
+            bands = bands,
+            validation_split = validation_split
+        )
+        # Obtain the train and the test data
+        train_samples <- train_test_data[["train_samples"]]
+        test_samples <- train_test_data[["test_samples"]]
 
-        if (!is.null(samples_validation)) {
-            .check_samples_validation(
-                samples_validation = samples_validation, labels = labels,
-                timeline = timeline, bands = bands
-            )
-            # Test samples are extracted from validation data
-            test_samples <- .predictors(samples_validation)
-            test_samples <- .pred_normalize(
-                pred = test_samples, stats = ml_stats
-            )
-        } else {
-            # Split the data into training and validation data sets
-            # Create partitions different splits of the input data
-            test_samples <- .pred_sample(
-                pred = train_samples, frac = validation_split
-            )
-            # Remove the lines used for validation
-            sel <- !train_samples[["sample_id"]] %in%
-                test_samples[["sample_id"]]
-            train_samples <- train_samples[sel, ]
-        }
+        # Organize data for model training
         n_samples_train <- nrow(train_samples)
         n_samples_test <- nrow(test_samples)
-        # Shuffle the data
-        train_samples <- train_samples[sample(
-            nrow(train_samples), nrow(train_samples)
-        ), ]
-        test_samples <- test_samples[sample(
-            nrow(test_samples), nrow(test_samples)
-        ), ]
-        # Organize data for model training
         train_x <- array(
             data = as.matrix(.pred_features(train_samples)),
             dim = c(n_samples_train, n_times, n_bands)
@@ -233,8 +204,10 @@ sits_resnet <- function(samples = NULL,
             dim = c(n_samples_test, n_times, n_bands)
         )
         test_y <- unname(code_labels[.pred_references(test_samples)])
+
         # Set torch seed
-        torch::torch_manual_seed(sample.int(10^5, 1))
+        torch::torch_manual_seed(sample.int(100000L, 1L))
+        # Define the Resnet architecture
         # Block associated to ResNet
         resnet_block <- torch::nn_module(
             classname = "block_resnet",
@@ -245,21 +218,21 @@ sits_resnet <- function(samples = NULL,
                 self$conv_block1 <- .torch_batch_conv1D_batch_norm_relu(
                     input_dim   = in_channels,
                     output_dim  = out_channels,
-                    kernel_size = kernels[[1]],
+                    kernel_size = kernels[1],
                     padding     = "same"
                 )
                 # create second convolution block
                 self$conv_block2 <- .torch_conv1D_batch_norm_relu(
                     input_dim   = out_channels,
                     output_dim  = out_channels,
-                    kernel_size = kernels[[2]],
+                    kernel_size = kernels[2],
                     padding     = "same"
                 )
                 # create third convolution block
                 self$conv_block3 <- .torch_conv1D_batch_norm(
                     input_dim   = out_channels,
                     output_dim  = out_channels,
-                    kernel_size = kernels[[3]],
+                    kernel_size = kernels[3],
                     padding     = "same"
                 )
                 # create shortcut
@@ -282,29 +255,21 @@ sits_resnet <- function(samples = NULL,
                 return(x)
             }
         )
+        # create ResNet
         # Define the ResNet architecture
         resnet_model <- torch::nn_module(
             classname = "model_resnet",
             initialize = function(n_bands, n_times, n_labels, blocks, kernels) {
-                self$res_block1 <- resnet_block(n_bands,
-                                                blocks[[1]],
-                                                kernels
-                )
-                self$res_block2 <- resnet_block(blocks[[1]],
-                                                blocks[[2]],
-                                                kernels
-                )
-                self$res_block3 <- resnet_block(blocks[[2]],
-                                                blocks[[3]],
-                                                kernels
-                )
+                self$res_block1 <- resnet_block(n_bands, blocks[1], kernels)
+                self$res_block2 <- resnet_block(blocks[1], blocks[2], kernels)
+                self$res_block3 <- resnet_block(blocks[2], blocks[3], kernels)
                 self$gap <- torch::nn_adaptive_avg_pool1d(output_size = n_bands)
 
                 # flatten 3D tensor to 2D tensor
                 self$flatten <- torch::nn_flatten()
                 # classification using softmax
                 self$softmax <- torch::nn_sequential(
-                    torch::nn_linear(blocks[[3]] * n_bands, n_labels),
+                    torch::nn_linear(blocks[3] * n_bands, n_labels),
                     torch::nn_softmax(dim = -1)
                 )
             },
@@ -319,7 +284,9 @@ sits_resnet <- function(samples = NULL,
                     self$softmax()
             }
         )
-        # train the model using luz
+        # train with CPU or GPU?
+        cpu_train <- .torch_cpu_train()
+        # Train the model using luz
         torch_model <-
             luz::setup(
                 module = resnet_model,
@@ -327,6 +294,9 @@ sits_resnet <- function(samples = NULL,
                 metrics = list(luz::luz_metric_accuracy()),
                 optimizer = optimizer
             ) |>
+            luz::set_opt_hparams(
+                !!!optim_params_function
+            ) |>
             luz::set_hparams(
                 n_bands  = n_bands,
                 n_times  = n_times,
@@ -334,9 +304,6 @@ sits_resnet <- function(samples = NULL,
                 blocks   = blocks,
                 kernels  = kernels
             ) |>
-            luz::set_opt_hparams(
-                !!!optim_params_function
-            ) |>
             luz::fit(
                 data = list(train_x, train_y),
                 epochs = epochs,
@@ -344,9 +311,9 @@ sits_resnet <- function(samples = NULL,
                 callbacks = list(
                     luz::luz_callback_early_stopping(
                         monitor = "valid_loss",
-                        mode = "min",
                         patience = patience,
-                        min_delta = min_delta
+                        min_delta = min_delta,
+                        mode = "min"
                     ),
                     luz::luz_callback_lr_scheduler(
                         torch::lr_step,
@@ -354,6 +321,7 @@ sits_resnet <- function(samples = NULL,
                         gamma = lr_decay_rate
                     )
                 ),
+                accelerator = luz::accelerator(cpu = cpu_train),
                 dataloader_options = list(batch_size = batch_size),
                 verbose = verbose
             )
@@ -366,11 +334,9 @@ sits_resnet <- function(samples = NULL,
             .check_require_packages("torch")
             # Set torch threads to 1
             # Note: function does not work on MacOS
-            suppressWarnings(torch::torch_set_num_threads(1))
+            suppressWarnings(torch::torch_set_num_threads(1L))
             # Unserialize model
             torch_model[["model"]] <- .torch_unserialize_model(serialized_model)
-            # Used to check values (below)
-            n_input_pixels <- nrow(values)
             # Transform input into a 3D tensor
             # Reshape the 2D matrix into a 3D array
             n_samples <- nrow(values)
@@ -378,17 +344,18 @@ sits_resnet <- function(samples = NULL,
             n_bands <- length(bands)
             # Performs data normalization
             values <- .pred_normalize(pred = values, stats = ml_stats)
+            # Represent matrix values as array
             values <- array(
                 data = as.matrix(values), dim = c(n_samples, n_times, n_bands)
             )
-            # if CUDA is available, transform to torch data set
-            # Load into GPU
-            if (torch::cuda_is_available()) {
-                values <- .as_dataset(values)
-                # We need to transform in a dataloader to use the batch size
-                values <- torch::dataloader(
-                    values, batch_size = 2^15
-                )
+            # GPU or CPU classification?
+            if (.torch_gpu_classification()) {
+                # Get batch size
+                batch_size <- sits_env[["batch_size"]]
+                # Transform the input array to a dataset
+                values <- .torch_as_dataset(values)
+                # Transform to dataloader to use the batch size
+                values <- torch::dataloader(values, batch_size = batch_size)
                 # Do GPU classification
                 values <- .try(
                     stats::predict(object = torch_model, values),
@@ -398,25 +365,18 @@ sits_resnet <- function(samples = NULL,
                 # Do CPU classification
                 values <- stats::predict(object = torch_model, values)
             }
-            # Convert to tensor CPU
-            values <- torch::as_array(
-                x = torch::torch_tensor(values, device = "cpu")
-            )
-            .check_processed_values(
-                values = values, n_input_pixels = n_input_pixels
-            )
+            # Convert from tensor to array
+            values <- torch::as_array(values)
             # Update the columns names to labels
-            colnames(values) <- labels
-            return(values)
+            colnames(values) <- sample_labels
+            values
         }
         # Set model class
         predict_fun <- .set_class(
             predict_fun, "torch_model", "sits_model", class(predict_fun)
         )
-        return(predict_fun)
     }
     # If samples is informed, train a model and return a predict function
-    # Otherwise give back a train function to train the model later
-    result <- .factory_function(samples, train_fun)
-    return(result)
+    # Otherwise give back a train function to train model further
+    .factory_function(samples, train_fun)
 }
