@@ -3,7 +3,7 @@
 #' @name  sits_smooth
 #'
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #'
 #' @description Takes a set of classified raster layers with probabilities,
 #'              whose metadata is]created by \code{\link[sits]{sits_cube}},
@@ -30,9 +30,53 @@
 #'                           (character vector of length 1).
 #' @param  version           Version of the output
 #'                           (character vector of length 1).
+#' @param  progress          Check progress bar?
 #'
 #' @return A data cube.
 #'
+#' @note
+#' The main \code{sits} classification workflow has the following steps:
+#' \enumerate{
+#'      \item{\code{\link[sits]{sits_cube}}: selects a ARD image collection from
+#'          a cloud provider.}
+#'      \item{\code{\link[sits]{sits_cube_copy}}: copies an ARD image collection
+#'          from a cloud provider to a local directory for faster processing.}
+#'      \item{\code{\link[sits]{sits_regularize}}: create a regular data cube
+#'          from an ARD image collection.}
+#'      \item{\code{\link[sits]{sits_apply}}: create new indices by combining
+#'          bands of a  regular data cube (optional).}
+#'      \item{\code{\link[sits]{sits_get_data}}: extract time series
+#'          from a regular data cube based on user-provided labelled samples.}
+#'      \item{\code{\link[sits]{sits_train}}: train a machine learning
+#'          model based on image time series.}
+#'      \item{\code{\link[sits]{sits_classify}}: classify a data cube
+#'          using a machine learning model and obtain a probability cube.}
+#'      \item{\code{\link[sits]{sits_smooth}}: post-process a probability cube
+#'          using a spatial smoother to remove outliers and
+#'          increase spatial consistency.}
+#'      \item{\code{\link[sits]{sits_label_classification}}: produce a
+#'          classified map by selecting the label with the highest probability
+#'          from a smoothed cube.}
+#' }
+#' Machine learning algorithms rely on training samples that are
+#' derived from “pure” pixels, hand-picked by users to represent
+#' the desired output classes.
+#' Given the presence of mixed pixels in images regardless of resolution,
+#' and the considerable data variability within each class,
+#' these classifiers often produce results with misclassified pixels.
+#'
+#' Post-processing the results of \code{\link[sits]{sits_classify}}
+#' using \code{sits_smooth} reduces salt-and-pepper and border effects.
+#' By minimizing noise, \code{sits_smooth} brings a significant gain
+#' in the overall accuracy and interpretability of the final output.
+#'
+#' @references
+#' Gilberto Camara, Renato Assunção, Alexandre Carvalho, Rolf Simões,
+#' Felipe Souza, Felipe Carlos, Anielli Souza, Ana Rorato,
+#' Ana Paula Dal’Asta, “Bayesian inference
+#' for post-processing of remote sensing image classification”.
+#' Remote Sensing, 16(23), 4572, 2024. DOI: https://doi.org/10.3390/rs16234572.
+#'
 #' @examples
 #' if (sits_run_examples()) {
 #'     # create am xgboost model
@@ -73,33 +117,34 @@ sits_smooth <- function(cube, ...) {
 sits_smooth.probs_cube <- function(cube, ...,
                                    window_size = 9L,
                                    neigh_fraction = 0.5,
-                                   smoothness = 20L,
+                                   smoothness = 20.0,
                                    exclusion_mask = NULL,
                                    memsize = 4L,
                                    multicores = 2L,
                                    output_dir,
-                                   version = "v1") {
+                                   version = "v1",
+                                   progress = TRUE) {
     # Check if cube has probability data
     .check_raster_cube_files(cube)
     # check window size
-    .check_int_parameter(window_size, min = 3, max = 33, is_odd = TRUE)
+    .check_int_parameter(window_size, min = 3L, max = 33L, is_odd = TRUE)
     # check neighborhood fraction
-    .check_num_parameter(neigh_fraction, min = 0., max = 1.0)
+    .check_num_parameter(neigh_fraction, min = 0.0, max = 1.0)
     # Check memsize
-    .check_int_parameter(memsize, min = 1, max = 16384)
+    .check_int_parameter(memsize, min = 1L, max = 16384L)
     # Check multicores
-    .check_int_parameter(multicores, min = 1, max = 2048)
+    .check_int_parameter(multicores, min = 1L, max = 2048L)
     # Check output dir
     output_dir <- path.expand(output_dir)
     .check_output_dir(output_dir)
-    # Check version
-    version <- .check_version(version)
+    # Check version and progress
+    version <- .message_version(version)
     # get nlabels
     nlabels <- length(.cube_labels(cube))
     # Check smoothness
     .check_smoothness(smoothness, nlabels)
     # Prepare smoothness parameter
-    if (length(smoothness) == 1) {
+    if (length(smoothness) == 1L) {
         smoothness <- rep(smoothness, nlabels)
     }
     # version is case-insensitive in sits
@@ -107,7 +152,7 @@ sits_smooth.probs_cube <- function(cube, ...,
     # get nlabels
     nlabels <- length(.cube_labels(cube))
     # Prepare smoothness parameter
-    if (length(smoothness) == 1) {
+    if (length(smoothness) == 1L) {
         smoothness <- rep(smoothness, nlabels)
     }
 
@@ -116,12 +161,12 @@ sits_smooth.probs_cube <- function(cube, ...,
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(cube)))
     # Overlapping pixels
-    overlap <- ceiling(window_size / 2) - 1
+    overlap <- ceiling(window_size / 2L) - 1L
     # Check minimum memory needed to process one block
     job_block_memsize <- .jobs_block_memsize(
         block_size = .block_size(block = block, overlap = overlap),
-        npaths = length(.tile_labels(cube)) * 2,
-        nbytes = 8,
+        npaths = length(.tile_labels(cube)) * 2L,
+        nbytes = 8L,
         proc_bloat = .conf("processing_bloat_cpu")
     )
     # Update multicores parameter
@@ -152,7 +197,8 @@ sits_smooth.probs_cube <- function(cube, ...,
         multicores = multicores,
         memsize = memsize,
         output_dir = output_dir,
-        version = version
+        version = version,
+        progress = progress
     )
 }
 #' @rdname sits_smooth
@@ -162,7 +208,7 @@ sits_smooth.probs_vector_cube <- function(cube, ...) {
 }
 #' @rdname sits_smooth
 #' @export
-sits_smooth.raster_cube <- function(cube,...) {
+sits_smooth.raster_cube <- function(cube, ...) {
     stop(.conf("messages", "sits_smooth_default"))
 }
 #' @rdname sits_smooth
@@ -172,12 +218,12 @@ sits_smooth.derived_cube <- function(cube, ...) {
 }
 #' @rdname sits_smooth
 #' @export
-sits_smooth.default <- function(cube,...) {
+sits_smooth.default <- function(cube, ...) {
     cube <- tibble::as_tibble(cube)
-    if (all(.conf("sits_cube_cols") %in% colnames(cube)))
+    if (all(.conf("sits_cube_cols") %in% colnames(cube))) {
         cube <- .cube_find_class(cube)
-    else
+    } else {
         stop(.conf("messages", "sits_smooth_default"))
-    cube <- sits_smooth(cube,...)
-    return(cube)
+    }
+    sits_smooth(cube, ...)
 }
