@@ -1,43 +1,13 @@
-#' @title Use SOM for quality analysis of time series samples
-#' @name sits_som
+#' @title Build a SOM for quality analysis of time series samples
+#' @name sits_som_map
 #'
 #' @author Lorena Alves, \email{lorena.santos@@inpe.br}
 #' @author Karine Ferreira. \email{karine.ferreira@@inpe.br}
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
 #' @description These function use self-organized maps to perform
-#' quality analysis in satellite image time series
+#' quality analysis in satellite image time series.
 #'
-#' \code{sits_som_map()} creates a SOM map, where high-dimensional data
-#' is mapped into a two dimensional map, keeping the topological relations
-#' between data patterns. Each sample is assigned to a neuron,
-#' and neurons are placed in the grid based on similarity.
-#'
-#' \code{sits_som_evaluate_cluster()} analyses the neurons of the SOM map,
-#' and builds clusters based on them. Each cluster is a neuron
-#' or a set of neuron categorized with same label.
-#' It produces a tibble with the percentage of mixture of classes
-#' in each cluster.
-#'
-#' \code{sits_som_clean_samples()} evaluates the quality of the samples
-#' based on the results of the SOM map.  The algorithm identifies noisy samples,
-#' using `prior_threshold` for the prior probability
-#' and `posterior_threshold` for the posterior probability.
-#' Each sample receives an evaluation tag, according to the following rule:
-#' (a) If the prior probability is < `prior_threshold`, the sample is tagged
-#' as "remove";
-#' (b) If the prior probability is >= `prior_threshold` and the posterior
-#' probability is >=`posterior_threshold`, the sample is tagged as "clean";
-#' (c) If the prior probability is >= `posterior_threshold` and
-#' the posterior probability is < `posterior_threshold`, the sample is tagged as
-#' "analyze" for further inspection.
-#' The user can define which tagged samples will be returned using the "keep"
-#' parameter, with the following options: "clean", "analyze", "remove".
-#'
-#' @references
-#' Lorena Santos, Karine Ferreira, Gilberto Camara, Michelle Picoli,
-#' Rolf Simoes, “Quality control and class noise reduction of satellite
-#' image time series”. ISPRS Journal of Photogrammetry and Remote Sensing,
-#' vol. 177, pp 75-88, 2021. https://doi.org/10.1016/j.isprsjprs.2021.04.014.
 #'
 #'
 #' @param data           A tibble with samples to be clustered.
@@ -56,14 +26,50 @@
 #'                       \code{"online"}, \code{"batch"}, and \code{"pbatch"}.
 #'                       The default learning algorithm is \code{"online"}.
 #'
-#' @note To learn more about the learning algorithms, check the
+#' @note
+#' \code{\link[sits]{sits_som_map}} creates a SOM map, where
+#' high-dimensional data is mapped into a two dimensional map,
+#' keeping the topological relations
+#' between data patterns. Each sample is assigned to a neuron,
+#' and neurons are placed in the grid based on similarity.
+#'
+#' \code{\link[sits]{sits_som_evaluate_cluster}} analyses the neurons of
+#' the SOM map, and builds clusters based on them. Each cluster is a neuron
+#' or a set of neuron categorized with same label.
+#' It produces a tibble with the percentage of mixture of classes
+#' in each cluster.
+#'
+#' \code{\link[sits]{sits_som_clean_samples}} evaluates sample quality
+#' based on the results of the SOM map.  The algorithm identifies noisy samples,
+#' using `prior_threshold` for the prior probability
+#' and `posterior_threshold` for the posterior probability.
+#' Each sample receives an evaluation tag, according to the following rule:
+#' (a) If the prior probability is < `prior_threshold`, the sample is tagged
+#' as "remove";
+#' (b) If the prior probability is >= `prior_threshold` and the posterior
+#' probability is >=`posterior_threshold`, the sample is tagged as "clean";
+#' (c) If the prior probability is >= `posterior_threshold` and
+#' the posterior probability is < `posterior_threshold`, the sample is tagged as
+#' "analyze" for further inspection.
+#'
+#' The user can define which tagged samples will be returned using the "keep"
+#' parameter, with the following options: "clean", "analyze", "remove".
+#'
+#' To learn more about the learning algorithms, check the
 #'       \code{\link[kohonen:supersom]{kohonen::supersom}} function.
 #'
-#' @note The \code{sits} package implements the \code{"dtw"} (Dynamic Time
+#' The \code{sits} package implements the \code{"dtw"} (Dynamic Time
 #'       Warping) similarity measure. The \code{"euclidean"} similarity
 #'       measurement come from the
 #'       \code{\link[kohonen:supersom]{kohonen::supersom (dist.fcts)}} function.
 #'
+#' @references
+#' Lorena Santos, Karine Ferreira, Gilberto Camara, Michelle Picoli,
+#' Rolf Simoes, “Quality control and class noise reduction of satellite
+#' image time series”. ISPRS Journal of Photogrammetry and Remote Sensing,
+#' vol. 177, pp 75-88, 2021. https://doi.org/10.1016/j.isprsjprs.2021.04.014.
+#'
+#'
 #' @return
 #' \code{sits_som_map()} produces a list with three members:
 #' (1) the samples tibble, with one additional column indicating
@@ -92,12 +98,12 @@
 #'
 #' @export
 sits_som_map <- function(data,
-                         grid_xdim = 10,
-                         grid_ydim = 10,
+                         grid_xdim = 10L,
+                         grid_ydim = 10L,
                          alpha = 1.0,
-                         rlen = 100,
+                         rlen = 100L,
                          distance = "dtw",
-                         som_radius = 2,
+                         som_radius = 2L,
                          mode = "online") {
     # set caller to show in errors
     .check_set_caller("sits_som_map")
@@ -112,12 +118,14 @@ sits_som_map <- function(data,
     # is are there more neurons than samples?
     n_samples <- nrow(data)
     # check recommended grid sizes
-    min_grid_size <- floor(sqrt(5 * sqrt(n_samples))) - 2
-    max_grid_size <- ceiling(sqrt(5 * sqrt(n_samples))) + 2
-    if (grid_xdim < min_grid_size || grid_xdim > max_grid_size)
-        warning(.conf("messages", "sits_som_map_grid_size"),
-                "(", min_grid_size, " ...", max_grid_size, ")"
+    min_grid_size <- floor(sqrt(5L * sqrt(n_samples))) - 2L
+    max_grid_size <- ceiling(sqrt(5L * sqrt(n_samples))) + 2L
+    if (grid_xdim < min_grid_size || grid_xdim > max_grid_size) {
+        warning(
+            .conf("messages", "sits_som_map_grid_size"),
+            "(", min_grid_size, " ...", max_grid_size, ")"
         )
+    }
     .check_that(n_samples > grid_xdim * grid_ydim)
     # get the time series
     time_series <- .values_ts(data, format = "bands_cases_dates")
@@ -154,7 +162,7 @@ sits_som_map <- function(data,
         som_radius
     )
     # get the list of labels for maximum a priori probability
-    lab_max <- seq(1:(grid_xdim * grid_ydim)) |>
+    lab_max <- seq_len(grid_xdim * grid_ydim) |>
         purrr::map(function(neuron_id) {
             labels_neuron <- dplyr::filter(
                 labelled_neurons,
@@ -170,7 +178,7 @@ sits_som_map <- function(data,
             label_max_final <- which.max(labels_neuron[["prior_prob"]])
             # if more than one sample has been mapped AND their max are the
             # same, then a posteriori probability is considered
-            if (length(number_of_label_max) > 1) {
+            if (length(number_of_label_max) > 1L) {
                 # Get the maximum posterior among the tied classes
                 max_post <- max(
                     labels_neuron[number_of_label_max, ][["post_prob"]]
@@ -187,15 +195,11 @@ sits_som_map <- function(data,
             } else {
                 label_max_final <- which.max(labels_neuron[["prior_prob"]])
             }
-            return(labels_neuron[label_max_final, ][["label_samples"]])
+            labels_neuron[label_max_final, ][["label_samples"]]
         })
     labels_max <- unlist(lab_max)
     # prepare a color assignment to the SOM map
     kohonen_obj[["neuron_label"]] <- labels_max
-    # only paint neurons if number of labels is greater than one
-    if (length(unique(labels_max)) > 1) {
-        kohonen_obj <- .som_paint_neurons(kohonen_obj)
-    }
     # return the som_map object
     som_map <-
         list(
@@ -209,6 +213,28 @@ sits_som_map <- function(data,
 
 #' @title Cleans the samples based on SOM map information
 #' @name sits_som_clean_samples
+#' @author Lorena Alves, \email{lorena.santos@@inpe.br}
+#' @author Karine Ferreira. \email{karine.ferreira@@inpe.br}
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @description
+#' \code{sits_som_clean_samples()} evaluates the quality of the samples
+#' based on the results of the SOM map.
+#'
+#' @note
+#' The algorithm identifies noisy samples,
+#' using `prior_threshold` for the prior probability
+#' and `posterior_threshold` for the posterior probability.
+#' Each sample receives an evaluation tag, according to the following rule:
+#' (a) If the prior probability is < `prior_threshold`, the sample is tagged
+#' as "remove";
+#' (b) If the prior probability is >= `prior_threshold` and the posterior
+#' probability is >=`posterior_threshold`, the sample is tagged as "clean";
+#' (c) If the prior probability is >= `posterior_threshold` and
+#' the posterior probability is < `posterior_threshold`, the sample is tagged as
+#' "analyze" for further inspection.
+#' The user can define which tagged samples will be returned using the "keep"
+#' parameter, with the following options: "clean", "analyze", "remove".
+#'
 #' @param som_map              Returned by \code{\link[sits]{sits_som_map}}.
 #' @param prior_threshold      Threshold of conditional probability
 #'                             (frequency of samples assigned to the
@@ -220,6 +246,7 @@ sits_som_map <- function(data,
 #' @return tibble with an two additional columns.
 #' The first indicates if each sample is clean, should be analyzed or
 #' should be removed. The second is the posterior probability of the sample.
+#' The "keep" parameter indicates which
 #'
 #' @examples
 #' if (sits_run_examples()) {
@@ -239,7 +266,7 @@ sits_som_map <- function(data,
 sits_som_clean_samples <- function(som_map,
                                    prior_threshold = 0.6,
                                    posterior_threshold = 0.6,
-                                   keep = c("clean", "analyze")) {
+                                   keep = c("clean", "analyze", "remove")) {
     # set caller to show in errors
     .check_set_caller("sits_som_clean_samples")
     # Sanity check
@@ -249,15 +276,6 @@ sits_som_clean_samples <- function(som_map,
         within = .conf("som_outcomes"),
         msg = .conf("messages", "sits_som_clean_samples_keep")
     )
-    # function to detect of class noise
-    .detect_class_noise <- function(prior_prob, post_prob) {
-        ifelse(prior_prob >= prior_threshold &
-            post_prob >= posterior_threshold, "clean",
-            ifelse(prior_prob >= prior_threshold &
-                 post_prob < posterior_threshold, "analyze", "remove"
-            )
-        )
-    }
     # extract tibble from SOM map
     data <- som_map[["data"]] |>
         dplyr::select(
@@ -266,7 +284,6 @@ sits_som_clean_samples <- function(som_map,
             "start_date",
             "end_date",
             "label",
-            "cube",
             "time_series",
             "id_sample",
             "id_neuron"
@@ -275,14 +292,13 @@ sits_som_clean_samples <- function(som_map,
             by = c("id_neuron", label = "label_samples")
         ) |>
         dplyr::mutate(
-            eval = .detect_class_noise(
-                .data[["prior_prob"]],
-                .data[["post_prob"]]
+            eval = ifelse(.data[["prior_prob"]] >= prior_threshold &
+                .data[["post_prob"]] >= posterior_threshold, "clean",
+            ifelse(.data[["prior_prob"]] >= prior_threshold &
+                .data[["post_prob"]] < posterior_threshold, "analyze",
+            "remove"
+            )
             )
-        ) |>
-        dplyr::select(
-            -"count",
-            -"prior_prob"
         ) |>
         dplyr::filter(.data[["eval"]] %in% keep)
 
@@ -294,6 +310,9 @@ sits_som_clean_samples <- function(som_map,
 
 #' @title Evaluate cluster
 #' @name sits_som_evaluate_cluster
+#' @author Lorena Alves, \email{lorena.santos@@inpe.br}
+#' @author Karine Ferreira. \email{karine.ferreira@@inpe.br}
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @description
 #' \code{sits_som_evaluate_cluster()} produces a tibble with the clusters
 #' found by the SOM map. For each cluster, it provides the percentage
@@ -342,17 +361,17 @@ sits_som_evaluate_cluster <- function(som_map) {
     ))
     # get dimensions (rows and col)
     # rows are  original classes of samples
-    dim_row <- dim(confusion_matrix)[[1]]
+    dim_row <- dim(confusion_matrix)[[1L]]
     #  cols are  clusters
-    dim_col <- dim(confusion_matrix)[[2]]
+    dim_col <- dim(confusion_matrix)[[2L]]
     # estimate the purity index per cluster
-    cluster_purity_lst <- seq_len(dim_col - 1) |>
+    cluster_purity_lst <- seq_len(dim_col - 1L) |>
         purrr::map(function(d) {
-            current_col <- confusion_matrix[1:dim_row - 1, d]
+            current_col <- confusion_matrix[seq_len(dim_row - 1L), d]
             current_col_total <- confusion_matrix[dim_row, d]
             # get mixture percentage per cluster
             mixture_percentage <- as.numeric(
-                (current_col / current_col_total) * 100
+                (current_col / current_col_total) * 100L
             )
             nrows <- length(mixture_percentage)
             current_class_ambiguity <- tibble::tibble(
@@ -362,27 +381,29 @@ sits_som_evaluate_cluster <- function(som_map) {
                 mixture_percentage = mixture_percentage
             )
             # remove lines where mix_percentege is zero
-            current_class_ambiguity <- dplyr::filter(
+            dplyr::filter(
                 current_class_ambiguity,
-                .data[["mixture_percentage"]] > 0
+                .data[["mixture_percentage"]] > 0.0
             )
-            return(current_class_ambiguity)
         })
     purity_by_cluster <- do.call(rbind, cluster_purity_lst)
     class(purity_by_cluster) <- c(
         "som_evaluate_cluster",
         class(purity_by_cluster)
     )
-    return(purity_by_cluster)
+    purity_by_cluster
 }
 #' @title Evaluate cluster
 #' @name sits_som_remove_samples
+#' @author Lorena Alves, \email{lorena.santos@@inpe.br}
+#' @author Karine Ferreira. \email{karine.ferreira@@inpe.br}
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #' @description
 #' Remove samples from a given class inside a neuron of another class
 #' @param som_map   A SOM map produced by the som_map() function
 #' @param som_eval  An evaluation produced by the som_eval() function
 #' @param class_cluster Dominant class of a set of neurons
-#' @param class_remove  Class to be removed from the neurons of the "class_cluster"
+#' @param class_remove  Class to be removed from the neurons of "class_cluster"
 #' @return A new set of samples with the desired class neurons remove
 #' @examples
 #' if (sits_run_examples()) {
@@ -391,26 +412,35 @@ sits_som_evaluate_cluster <- function(som_map) {
 #'     # evaluate the som map and create clusters
 #'     som_eval <- sits_som_evaluate_cluster(som_map)
 #'     # clean the samples
-#'     new_samples <- sits_som_remove_samples(som_map, som_eval, "Pasture", "Cerrado")
+#'     new_samples <- sits_som_remove_samples(
+#'         som_map, som_eval,
+#'         "Pasture", "Cerrado"
+#'     )
 #' }
 #' @export
-sits_som_remove_samples <- function(som_map, som_eval, class_cluster, class_remove){
-
+sits_som_remove_samples <- function(som_map,
+                                    som_eval,
+                                    class_cluster,
+                                    class_remove) {
     # get the samples with id_neuron
     data <- som_map$data
     # get the samples by neurons
     neurons <- som_map$labelled_neurons
 
-    neurons_class_1 <- dplyr::filter(neurons, .data[["label_samples"]] == class_cluster
-                                     & .data[["prior_prob"]] > 0.50)
+    neurons_class_1 <- dplyr::filter(
+        neurons,
+        .data[["label_samples"]] == class_cluster,
+        .data[["prior_prob"]] > 0.50
+    )
     id_neurons_class_1 <- neurons_class_1[["id_neuron"]]
     # find samples of class2 in neurons of class1
-    samples_remove <- dplyr::filter(data, .data[["label"]] == class_remove &
-                                        .data[["id_neuron"]] %in% id_neurons_class_1)
+    samples_remove <- dplyr::filter(
+        data,
+        .data[["label"]] == class_remove,
+        .data[["id_neuron"]] %in% id_neurons_class_1
+    )
     # get the id of the samples to be removed
     id_samples_remove <- samples_remove[["id_sample"]]
     # obtain the new samples
-    new_samples <- dplyr::filter(data, !(.data[["id_sample"]] %in% id_samples_remove))
-    # return the new samples
-    return(new_samples)
+    dplyr::filter(data, !(.data[["id_sample"]] %in% id_samples_remove))
 }
