@@ -3,7 +3,7 @@
 #'
 #' @author Charlotte Pelletier, \email{charlotte.pelletier@@univ-ubs.fr}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @author Felipe Souza, \email{lipecaso@@gmail.com}
 #'
 #' @description Use a TempCNN algorithm to classify data, which has
@@ -11,6 +11,14 @@
 #' Users can define the depth of the 1D network, as well as
 #' the number of perceptron layers.
 #'
+#' @note
+#' \code{sits} provides a set of default values for all classification models.
+#' These settings have been chosen based on testing by the authors.
+#' Nevertheless, users can control all parameters for each model.
+#' Novice users can rely on the default values,
+#' while experienced ones can fine-tune deep learning models
+#' using \code{\link[sits]{sits_tuning}}.
+#'
 #' This function is based on the paper by Charlotte Pelletier referenced below.
 #' If you use this method, please cite the original tempCNN paper.
 #'
@@ -59,8 +67,10 @@
 #' @examples
 #' if (sits_run_examples()) {
 #'     # create a TempCNN model
-#'     torch_model <- sits_train(samples_modis_ndvi,
-#'                sits_tempcnn(epochs = 20, verbose = TRUE))
+#'     torch_model <- sits_train(
+#'         samples_modis_ndvi,
+#'         sits_tempcnn(epochs = 20, verbose = TRUE)
+#'     )
 #'     # plot the model
 #'     plot(torch_model)
 #'     # create a data cube from local files
@@ -91,13 +101,13 @@
 #' @export
 sits_tempcnn <- function(samples = NULL,
                          samples_validation = NULL,
-                         cnn_layers = c(64, 64, 64),
-                         cnn_kernels = c(5, 5, 5),
+                         cnn_layers = c(64L, 64L, 64L),
+                         cnn_kernels = c(5L, 5L, 5L),
                          cnn_dropout_rates = c(0.20, 0.20, 0.20),
-                         dense_layer_nodes = 256,
+                         dense_layer_nodes = 256L,
                          dense_layer_dropout_rate = 0.50,
-                         epochs = 150,
-                         batch_size = 64,
+                         epochs = 150L,
+                         batch_size = 64L,
                          validation_split = 0.2,
                          optimizer = torch::optim_adamw,
                          opt_hparams = list(
@@ -105,56 +115,61 @@ sits_tempcnn <- function(samples = NULL,
                              eps = 1.0e-08,
                              weight_decay = 1.0e-06
                          ),
-                         lr_decay_epochs = 1,
+                         lr_decay_epochs = 1L,
                          lr_decay_rate = 0.95,
-                         patience = 20,
+                         patience = 20L,
                          min_delta = 0.01,
                          verbose = FALSE) {
     # set caller for error msg
     .check_set_caller("sits_tempcnn")
     # Verifies if 'torch' and 'luz' packages is installed
     .check_require_packages(c("torch", "luz"))
+    # documentation mode? verbose is FALSE
+    verbose <- .message_verbose(verbose)
     # Function that trains a torch model based on samples
     train_fun <- function(samples) {
         # does not support working with DEM or other base data
-        if (inherits(samples, "sits_base"))
+        if (inherits(samples, "sits_base")) {
             stop(.conf("messages", "sits_train_base_data"), call. = FALSE)
+        }
         # Avoid add a global variable for 'self'
         self <- NULL
         # Check validation_split parameter if samples_validation is not passed
         if (is.null(samples_validation)) {
-            .check_num_parameter(validation_split, exclusive_min = 0, max = 0.5)
+            .check_num_parameter(validation_split, exclusive_min = 0.0, max = 0.5)
         }
         # Preconditions
-        .pre_sits_tempcnn(samples = samples, cnn_layers = cnn_layers,
-                          cnn_kernels = cnn_kernels,
-                          cnn_dropout_rates = cnn_dropout_rates,
-                          dense_layer_nodes = dense_layer_nodes,
-                          dense_layer_dropout_rate = dense_layer_dropout_rate,
-                          epochs = epochs, batch_size = batch_size,
-                          lr_decay_epochs = lr_decay_epochs,
-                          lr_decay_rate = lr_decay_rate,
-                          patience = patience, min_delta = min_delta,
-                          verbose = verbose)
+        .check_pre_sits_tempcnn(
+            samples = samples, cnn_layers = cnn_layers,
+            cnn_kernels = cnn_kernels,
+            cnn_dropout_rates = cnn_dropout_rates,
+            dense_layer_nodes = dense_layer_nodes,
+            dense_layer_dropout_rate = dense_layer_dropout_rate,
+            epochs = epochs, batch_size = batch_size,
+            lr_decay_epochs = lr_decay_epochs,
+            lr_decay_rate = lr_decay_rate,
+            patience = patience, min_delta = min_delta,
+            verbose = verbose
+        )
         # Check opt_hparams
         # Get parameters list and remove the 'param' parameter
-        optim_params_function <- formals(optimizer)[-1]
+        optim_params_function <- formals(optimizer)[-1L]
         .check_opt_hparams(opt_hparams, optim_params_function)
         optim_params_function <- utils::modifyList(
             x = optim_params_function,
             val = opt_hparams
         )
-        # Samples labels
-        labels <- .samples_labels(samples)
-        # Samples bands
+        # Sample labels
+        sample_labels <- .samples_labels(samples)
+        # Sample bands
         bands <- .samples_bands(samples)
-        # Samples timeline
+        # Sample timeline
         timeline <- .samples_timeline(samples)
         # Create numeric labels vector
-        code_labels <- seq_along(labels)
-        names(code_labels) <- labels
+        code_labels <- seq_along(sample_labels)
+        names(code_labels) <- sample_labels
         # Number of labels, bands, and number of samples (used below)
-        n_labels <- length(labels)
+        n_labels <- length(sample_labels)
         n_bands <- length(bands)
         n_times <- .samples_ntimes(samples)
         # Data normalization
@@ -165,7 +180,7 @@ sits_tempcnn <- function(samples = NULL,
             samples = samples,
             samples_validation = samples_validation,
             ml_stats = ml_stats,
-            labels = labels,
+            labels = sample_labels,
             code_labels = code_labels,
             timeline = timeline,
             bands = bands,
@@ -191,7 +206,7 @@ sits_tempcnn <- function(samples = NULL,
         test_y <- unname(code_labels[.pred_references(test_samples)])
 
         # Set torch seed
-        torch::torch_manual_seed(sample.int(10^5, 1))
+        torch::torch_manual_seed(sample.int(100000L, 1L))
         # Define the TempCNN architecture
         tcnn_model <- torch::nn_module(
             classname = "model_tcnn",
@@ -207,32 +222,32 @@ sits_tempcnn <- function(samples = NULL,
                 # first module - transform input to hidden dims
                 self$conv_bn_relu1 <- .torch_conv1D_batch_norm_relu_dropout(
                     input_dim    = n_bands,
-                    output_dim   = hidden_dims[[1]],
-                    kernel_size  = kernel_sizes[[1]],
-                    padding      = as.integer(kernel_sizes[[1]] %/% 2),
-                    dropout_rate = dropout_rates[[1]]
+                    output_dim   = hidden_dims[[1L]],
+                    kernel_size  = kernel_sizes[[1L]],
+                    padding      = as.integer(kernel_sizes[[1L]] %/% 2L),
+                    dropout_rate = dropout_rates[[1L]]
                 )
                 # second module - 1D CNN
                 self$conv_bn_relu2 <- .torch_conv1D_batch_norm_relu_dropout(
-                    input_dim    = hidden_dims[[1]],
-                    output_dim   = hidden_dims[[2]],
-                    kernel_size  = kernel_sizes[[2]],
-                    padding      = as.integer(kernel_sizes[[2]] %/% 2),
-                    dropout_rate = dropout_rates[[2]]
+                    input_dim    = hidden_dims[[1L]],
+                    output_dim   = hidden_dims[[2L]],
+                    kernel_size  = kernel_sizes[[2L]],
+                    padding      = as.integer(kernel_sizes[[2L]] %/% 2L),
+                    dropout_rate = dropout_rates[[2L]]
                 )
                 # third module - 1D CNN
                 self$conv_bn_relu3 <- .torch_conv1D_batch_norm_relu_dropout(
-                    input_dim    = hidden_dims[[2]],
-                    output_dim   = hidden_dims[[3]],
-                    kernel_size  = kernel_sizes[[3]],
-                    padding      = as.integer(kernel_sizes[[3]] %/% 2),
-                    dropout_rate = dropout_rates[[3]]
+                    input_dim    = hidden_dims[[2L]],
+                    output_dim   = hidden_dims[[3L]],
+                    kernel_size  = kernel_sizes[[3L]],
+                    padding      = as.integer(kernel_sizes[[3L]] %/% 2L),
+                    dropout_rate = dropout_rates[[3L]]
                 )
                 # flatten 3D tensor to 2D tensor
                 self$flatten <- torch::nn_flatten()
                 # create a dense tensor
                 self$dense <- .torch_linear_batch_norm_relu_dropout(
-                    input_dim    = hidden_dims[[3]] * n_times,
+                    input_dim    = hidden_dims[[3L]] * n_times,
                     output_dim   = dense_layer_nodes,
                     dropout_rate = dense_layer_dropout_rate
                 )
@@ -245,7 +260,7 @@ sits_tempcnn <- function(samples = NULL,
             forward = function(x) {
                 # input is 3D n_samples x n_times x n_bands
                 x <- x |>
-                    torch::torch_transpose(2, 3) |>
+                    torch::torch_transpose(2L, 3L) |>
                     self$conv_bn_relu1() |>
                     self$conv_bn_relu2() |>
                     self$conv_bn_relu3() |>
@@ -307,11 +322,9 @@ sits_tempcnn <- function(samples = NULL,
             .check_require_packages("torch")
             # Set torch threads to 1
             # Note: function does not work on MacOS
-            suppressWarnings(torch::torch_set_num_threads(1))
+            suppressWarnings(torch::torch_set_num_threads(1L))
             # Unserialize model
             torch_model[["model"]] <- .torch_unserialize_model(serialized_model)
-            # Used to check values (below)
-            input_pixels <- nrow(values)
             # Transform input into a 3D tensor
             # Reshape the 2D matrix into a 3D array
             n_samples <- nrow(values)
@@ -343,17 +356,15 @@ sits_tempcnn <- function(samples = NULL,
             # Convert from tensor to array
             values <- torch::as_array(values)
             # Update the columns names to labels
-            colnames(values) <- labels
-            return(values)
+            colnames(values) <- sample_labels
+            values
         }
         # Set model class
         predict_fun <- .set_class(
             predict_fun, "torch_model", "sits_model", class(predict_fun)
         )
-        return(predict_fun)
     }
     # If samples is informed, train a model and return a predict function
     # Otherwise give back a train function to train model further
-    result <- .factory_function(samples, train_fun)
-    return(result)
+    .factory_function(samples, train_fun)
 }
