@@ -66,9 +66,9 @@ sits_to_xlsx.list <- function(acc, file) {
     eo_n <- "(Sensitivity)|(Specificity)|(Pos Pred Value)|(Neg Pred Value)|(F1)"
     # defined the number of sheets
     num_sheets <- length(acc)
-    .check_that(length(num_sheets) >= 1)
+    .check_that(length(num_sheets) >= 1L)
     # save all elements of the list
-    purrr::map2(acc, 1:num_sheets, function(cf_mat, ind) {
+    purrr::map2(acc, seq_len(num_sheets), function(cf_mat, ind) {
         # create a worksheet for each confusion matrix
         if (!.has(cf_mat[["name"]])) {
             cf_mat[["name"]] <- paste0("sheet", ind)
@@ -83,20 +83,20 @@ sits_to_xlsx.list <- function(acc, file) {
         # write the confusion matrix table in the worksheet
         openxlsx::writeData(workbook, sheet_name, cf_mat[["table"]])
         # overall assessment (accuracy and kappa)
-        acc_kappa <- as.matrix(cf_mat[["overall"]][1:2])
+        acc_kappa <- as.matrix(cf_mat[["overall"]][1L:2L])
         # save the accuracy data in the worksheet
         openxlsx::writeData(
             wb = workbook,
             sheet = sheet_name,
             x = acc_kappa,
             rowNames = TRUE,
-            startRow = nrow(cf_mat[["table"]]) + 3,
-            startCol = 1
+            startRow = nrow(cf_mat[["table"]]) + 3L,
+            startCol = 1L
         )
         # obtain the per class accuracy assessment
-        if (dim(cf_mat[["table"]])[[1]] > 2) {
+        if (dim(cf_mat[["table"]])[[1L]] > 2L) {
             # per class accuracy assessment
-            acc_bc <- t(cf_mat[["byClass"]][, c(1:4, 7)])
+            acc_bc <- t(cf_mat[["byClass"]][, c(1L:4L, 7L)])
             # remove prefix from confusion matrix table
             colnames(acc_bc) <- new_names
             row.names(acc_bc) <- c(
@@ -110,13 +110,14 @@ sits_to_xlsx.list <- function(acc, file) {
             # this is the case of ony two classes
             # get the values of the User's and Producer's Accuracy
             acc_bc <- cf_mat[["byClass"]][grepl(
-                eo_n, names(cf_mat[["byClass"]]))]
+                eo_n, names(cf_mat[["byClass"]])
+            )]
             # get the names of the two classes
             nm <- row.names(cf_mat[["table"]])
             # the first class (called the "positive" class by caret)
             c1 <- cf_mat[["positive"]]
             # the second class
-            c2 <- nm[!(nm == cf_mat[["positive"]])]
+            c2 <- nm[(nm != cf_mat[["positive"]])]
             # make up the values of UA and PA for the two classes
             pa1 <- paste("Prod Acc ", c1)
             pa2 <- paste("Prod Acc ", c2)
@@ -126,18 +127,17 @@ sits_to_xlsx.list <- function(acc, file) {
             acc_bc <- as.matrix(acc_bc)
         }
         # save the per class data in the worksheet
-        start_row <- nrow(cf_mat[["table"]]) + 8
+        start_row <- nrow(cf_mat[["table"]]) + 8L
         openxlsx::writeData(
             wb = workbook,
             sheet = sheet_name,
             x = acc_bc,
             rowNames = TRUE,
             startRow = start_row,
-            startCol = 1
+            startCol = 1L
         )
     })
     # write the worksheets to the XLSX file
     openxlsx::saveWorkbook(workbook, file = file, overwrite = TRUE)
-
-    return(message(.conf("messages", "sits_to_xlsx_save"), file))
+    message(.conf("messages", "sits_to_xlsx_save"), file)
 }
