@@ -134,7 +134,24 @@ test_that("XGBoost", {
         sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
+test_that("LightGBM", {
+    model <- sits_train(
+        samples_modis_ndvi,
+        sits_lightgbm(
+            nrounds = 10
+        )
+    )
+    point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
+    point_class <- sits_classify(
+        data = point_ndvi,
+        ml_model = model,
+        progress = FALSE
+    )
 
+    expect_true(all(point_class$predicted[[1]]$class %in%
+                        sits_labels(samples_modis_ndvi)))
+    expect_true(nrow(sits_show_prediction(point_class)) == 17)
+})
 test_that("DL-MLP", {
     model <- sits_train(
         samples_modis_ndvi,
@@ -144,6 +161,7 @@ test_that("DL-MLP", {
             epochs = 5
         )
     )
+    expect_true(.ml_is_torch_model(model))
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
 
     point_class <- sits_classify(
@@ -187,6 +205,26 @@ test_that("TempCNN model", {
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
+test_that("resnet model", {
+    model <- sits_train(
+        samples_modis_ndvi,
+        sits_resnet(epochs = 10)
+    )
+
+    point_ndvi <- sits_select(point_mt_6bands,
+                              bands = "NDVI"
+    )
+    point_class <-
+        sits_classify(
+            data = point_ndvi,
+            ml_model = model,
+            progress = FALSE
+        )
+
+    expect_true(all(point_class$predicted[[1]]$class %in%
+                        sits_labels(samples_modis_ndvi)))
+    expect_true(nrow(sits_show_prediction(point_class)) == 17)
+})
 test_that("LightTAE model", {
     model <- sits_train(
         samples_modis_ndvi,
