@@ -17,16 +17,16 @@ test_that("Align dates", {
 test_that("Apply", {
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
     point2 <- sits_apply(point_ndvi,
-                         NDVI_norm = (NDVI - min(NDVI)) /
-                             (max(NDVI) - min(NDVI))
+        NDVI_norm = (NDVI - min(NDVI)) /
+            (max(NDVI) - min(NDVI))
     )
 
     expect_equal(sum((.tibble_time_series(point2))$NDVI_norm),
-                 101.5388,
-                 tolerance = 0.1
+        101.5388,
+        tolerance = 0.1
     )
 })
-test_that("Data frame",{
+test_that("Data frame", {
     point_df <- point_mt_6bands
     class(point_df) <- "data.frame"
     point_df_ndvi <- sits_select(point_df, bands = "NDVI")
@@ -108,7 +108,7 @@ test_that("Dates", {
 test_that("Bbox", {
     bbox <- sits_bbox(samples_modis_ndvi)
     expect_true(all(names(bbox) %in%
-                        c("xmin", "ymin", "xmax", "ymax", "crs")))
+        c("xmin", "ymin", "xmax", "ymax", "crs")))
     expect_true(bbox["xmin"] < -60.0)
 
     samples <- samples_modis_ndvi
@@ -116,6 +116,11 @@ test_that("Bbox", {
     bbox1 <- sits_bbox(samples)
     expect_equal(bbox1, bbox)
 
+    samples_df <- samples_modis_ndvi
+    class(samples_df) <- "data.frame"
+    bbox_df <- sits_bbox(samples_df)
+    expect_equal(bbox_df, bbox)
+
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     cube <- sits_cube(
         source = "BDC",
@@ -129,7 +134,7 @@ test_that("Bbox", {
     bbox3 <- sits_bbox(new_cube)
     expect_equal(bbox2, bbox3)
 
-    bad_cube <- cube[1,1:3]
+    bad_cube <- cube[1, 1:3]
     # create a raster cube
     bbox5 <- .try(
         {
@@ -185,7 +190,7 @@ test_that("Values", {
 
 test_that("Apply", {
     samples_ndwi <- sits_apply(point_mt_6bands,
-                               NDWI = (1.5) * (NIR - MIR) / (NIR + MIR)
+        NDWI = (1.5) * (NIR - MIR) / (NIR + MIR)
     )
 
     expect_true("NDWI" %in% sits_bands(samples_ndwi))
